@@ -122,8 +122,15 @@ namespace ARTICLE
 
         // 描画用
         Glib::RefPtr< Gdk::Window > m_window;
+#if GTKMM_CHECK_VERSION(3,0,0)
+        // cairomm 1.12.0 がメモリリークを起こしたので
+        // C API を使うことで問題を回避する
+        std::unique_ptr< cairo_t, void ( * )( cairo_t* ) > m_cr;
+        std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_backscreen;
+#else
         Glib::RefPtr< Gdk::GC > m_gc;
         Glib::RefPtr< Gdk::Pixmap > m_backscreen;
+#endif
         Glib::RefPtr< Pango::Layout > m_pango_layout;
         Glib::RefPtr< Pango::Context > m_context;
         RECTANGLE m_rect_backscreen; // バックスクリーンが描画されている範囲
@@ -143,11 +150,21 @@ namespace ARTICLE
         // 色
         int m_colorid_text;     // デフォルトの文字色
         int m_colorid_back;     // デフォルトの背景色
+#if GTKMM_CHECK_VERSION(3,0,0)
+        std::vector< Gdk::RGBA > m_color;
+#else
         std::vector< Gdk::Color > m_color;
+#endif
 
         // 枠
         bool m_draw_frame;  // 枠を描画する
+#if GTKMM_CHECK_VERSION(3,0,0)
+        // 枠線に隠れる部分のバックアップを分ける
+        std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_back_frame_top;
+        std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_back_frame_bottom;
+#else
         Glib::RefPtr< Gdk::Pixmap > m_back_frame; // 枠の背景
+#endif
         bool m_ready_back_frame;
 
         // 範囲選択
@@ -181,7 +198,11 @@ namespace ARTICLE
         int m_pre_pos_y; // ひとつ前のスクロールバーの位置。スクロールした時の差分量計算に使用する
         std::vector< int > m_jump_history;  // ジャンプ履歴
         bool m_cancel_change_adjust; // adjust の値変更イベントをキャンセル
+#if GTKMM_CHECK_VERSION(3,0,0)
+        std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_back_marker;
+#else
         Glib::RefPtr< Gdk::Pixmap > m_back_marker; // オートスクロールマーカの背景
+#endif
         RECTANGLE m_clip_marker;
         bool m_ready_back_marker;
         time_t m_wait_scroll;  // 処理落ちした時にスクロールにウエイトを入れる
@@ -214,6 +235,25 @@ namespace ARTICLE
         // 自分の書き込みに対するレスマークアイコン
         Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_refer_post;
 
+#if GTKMM_CHECK_VERSION(3,14,0)
+        // マウスのクリックとタッチスクリーンのタップ
+        Glib::RefPtr< Gtk::GestureMultiPress > m_gesture_multipress;
+
+        // タッチスクリーンのスクロール
+        Glib::RefPtr< Gtk::GesturePan > m_gesture_pan;
+        Glib::RefPtr< Gtk::GestureSwipe > m_gesture_swipe;
+        double m_drag_start_y;
+
+        // 慣性スクロール
+        struct DecelerationInfo
+        {
+            double elapsed; // 換算された経過時間
+            double initial_dy; // スケーリングされた初速度(pixcels/frame)
+            gint64 last_time; // 前回コールバックが呼び出された時間(frame)
+            guint id = 0; // コールバックのID
+        } m_deceleration;
+#endif
+
       public:
 
         SIG_BUTTON_PRESS sig_button_press(){ return m_sig_button_press; }
@@ -230,8 +270,8 @@ namespace ARTICLE
         ~DrawAreaBase();
 
         const std::string& get_url() const { return m_url; }
-        const int& width_client() const { return m_width_client; }
-        const int& height_client() const { return m_height_client; }
+        int width_client() const { return m_width_client; }
+        int height_client() const { return m_height_client; }
 
         void clock_in();
         void clock_in_smooth_scroll();
@@ -259,7 +299,7 @@ namespace ARTICLE
         void select_all(); 
 
         // 範囲選択中の文字列
-        const std::string str_selection(); 
+        std::string str_selection();
         const std::string& str_pre_selection() const { return m_selection.str_pre; }  // 一つ前の選択文字列
 
         // 範囲選択を開始したレス番号
@@ -438,9 +478,20 @@ namespace ARTICLE
         // 枠の描画
         void draw_frame();
 
+        // バックスクリーンを矩形で塗りつぶす
+        void fill_backscreen( const int colorid, int x, int y, int width, int height );
+
+        // Pixbufの内容をバックスクリーンに貼り付ける
+        void paint_backscreen( const Glib::RefPtr< Gdk::Pixbuf >& pixbuf,
+                               int src_x, int src_y, int dest_x, int dest_y, int width, int height );
+
         // スロット
         void slot_change_adjust();
+#if GTKMM_CHECK_VERSION(3,0,0)
+        bool slot_draw( const Cairo::RefPtr< Cairo::Context >& cr );
+#else
         bool slot_expose_event( GdkEventExpose* event );
+#endif
         bool slot_scroll_event( GdkEventScroll* event );
         bool slot_leave_notify_event( GdkEventCrossing* event );
         bool slot_visibility_notify_event( GdkEventVisibility* event );
@@ -452,6 +503,24 @@ namespace ARTICLE
 
         bool slot_key_press_event( GdkEventKey* event );
         bool slot_key_release_event( GdkEventKey* event );
+
+#if GTKMM_CHECK_VERSION(3,14,0)
+        void setup_event_controller();
+
+        void slot_multipress_pressed( int n_press, double x, double y );
+        void slot_multipress_released( int n_press, double x, double y );
+
+        void slot_pan_begin( double start_x, double start_y );
+        void slot_pan_update( double offset_x, double offset_y );
+        void slot_gesture_end( GdkEventSequence* sequence );
+
+        void slot_swipe( double velocity_x, double velocity_y );
+
+        // 慣性スクロール
+        static gboolean deceleration_tick_cb( GtkWidget* cwidget, GdkFrameClock* clock, gpointer );
+        gboolean deceleration_tick_impl( GdkFrameClock* clock );
+        void cancel_deceleration();
+#endif
     };
 
 
