@@ -33,7 +33,7 @@ namespace ARTICLE
       public:
 
         ArticleToolBar(); 
-        ~ArticleToolBar() noexcept {}
+        ~ArticleToolBar() noexcept;
 
         // タブが切り替わった時に呼び出される( Viewの情報を取得する )
         void set_view( SKELETON::View * view ) override;
