@@ -1469,8 +1469,8 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
             return;
         }
 
-        // http が無ければ付ける
-        if( url.find( "http://" ) != 0 && url.find( "https://" ) != 0 ) url = "http://" + url;
+        // http[s] が無ければ付ける
+        if( url.find( "://" ) == std::string::npos ) url = "http://" + url;
 
         // .htmlを取り除く
         JDLIB::Regex regex;
@@ -2060,7 +2060,7 @@ void BBSListViewBase::slot_sort( const int mode )
 //
 // path -> url 変換
 //
-const Glib::ustring BBSListViewBase::path2rawurl( const Gtk::TreePath& path )
+Glib::ustring BBSListViewBase::path2rawurl( const Gtk::TreePath& path )
 {
     Gtk::TreeModel::Row row = m_treeview.get_row( path );
     if( !row ) return Glib::ustring();
@@ -2070,7 +2070,7 @@ const Glib::ustring BBSListViewBase::path2rawurl( const Gtk::TreePath& path )
 
 
 // 移転をチェックするバージョン
-const Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
+Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
 {
     Gtk::TreeModel::Row row = m_treeview.get_row( path );
     if( !row ) return Glib::ustring();
@@ -2104,7 +2104,7 @@ const Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
 // 板の場合は boardbase
 // スレの場合は dat 型のアドレスを返す
 //
-const Glib::ustring BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
+Glib::ustring BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
 {
     if( ! row ) return Glib::ustring();
 
@@ -2135,7 +2135,7 @@ const Glib::ustring BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
 //
 // path -> name 変換
 //
-const Glib::ustring BBSListViewBase::path2name( const Gtk::TreePath& path )
+Glib::ustring BBSListViewBase::path2name( const Gtk::TreePath& path )
 {
     Gtk::TreeModel::Row row = m_treeview.get_row( path );
     if( !row ) return Glib::ustring();
@@ -2168,7 +2168,7 @@ int BBSListViewBase::row2type( const Gtk::TreeModel::Row& row )
 //
 // row -> name 変換
 //
-const Glib::ustring BBSListViewBase::row2name( const Gtk::TreeModel::Row& row )
+Glib::ustring BBSListViewBase::row2name( const Gtk::TreeModel::Row& row )
 {
     if( !row ) return Glib::ustring();
     return row[ m_columns.m_name ];
@@ -2421,7 +2421,7 @@ void BBSListViewBase::toggle_articleicon( const std::string& url )
     if( m_treestore->children().empty() ) return;
 
     // ツリーの中に無い場合は処理しない
-    if( ! m_set_thread.find_if( url ) ) return;
+    if( m_set_thread.find( url ) == m_set_thread.end() ) return;
 
     bool erase = true;
     int type = TYPE_THREAD;
@@ -2519,11 +2519,15 @@ void BBSListViewBase::select_item( const std::string& url )
 
     std::string url_item( url );
 
-    if( m_set_thread.find_if( url_item )
+    if( m_set_thread.find( url_item ) != m_set_thread.end()
             || m_set_image.find( url_item ) != m_set_image.end()){
         // スレまたは画像の場合
     }
     else {
+        // 板以外の履歴は処理しない
+        if( get_url() == URL_HISTTHREADVIEW || get_url() == URL_HISTCLOSEVIEW ||
+            get_url() == URL_HISTCLOSEIMGVIEW ) return;
+
         // 板の場合
         url_item = DBTREE::url_boardbase( url );
 
@@ -2923,7 +2927,7 @@ void BBSListViewBase::append_history()
 
     // ツリーにアイテムが含まれている場合は削除
     // 履歴はサブディレクトリが無いと仮定してサブディレクトリの探査はしない
-    if( ( ( *it_info ).type == TYPE_THREAD && m_set_thread.find_if( ( *it_info ).url ) )
+    if( ( ( *it_info ).type == TYPE_THREAD && m_set_thread.find( ( *it_info ).url ) != m_set_thread.end() )
         || ( ( ( *it_info ).type == TYPE_BOARD || ( *it_info ).type == TYPE_VBOARD )  && m_set_board.find( ( *it_info ).url ) != m_set_board.end() )
         || ( ( *it_info ).type == TYPE_IMAGE && m_set_image.find( ( *it_info ).url ) != m_set_image.end() )
         ){
@@ -3033,7 +3037,7 @@ void BBSListViewBase::get_threads( const size_t dirid, std::vector< std::string
 
 
 // 指定したidのディレクトリの名前を取得
-const std::string BBSListViewBase::get_dirname( const int dirid )
+std::string BBSListViewBase::get_dirname( const int dirid )
 {
     if( ! dirid ) return get_label();
 
