@@ -51,15 +51,6 @@ std::string CACHE::path_conf_bkup()
 }
 
 
-// 旧設定ファイル
-std::string CACHE::path_conf_old()
-{
-    std::string home = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
-
-    return home + "/.jdrc";
-}
-
-
 // セッション情報ファイル
 std::string CACHE::path_session()
 {
@@ -114,11 +105,6 @@ std::string CACHE::path_xml_listmain_bkup()
 {
     return CACHE::path_xml_listmain() + ".bkup";
 }
-// 1.9.5-beta070611以前
-std::string CACHE::path_xml_listmain_old()
-{
-    return CACHE::path_root() +  "list_main.xml";
-}
 
 
 // お気に入り
@@ -131,11 +117,6 @@ std::string CACHE::path_xml_favorite_bkup()
 {
     return CACHE::path_xml_favorite() + ".bkup";
 }
-// 1.9.5-beta070611以前
-std::string CACHE::path_xml_favorite_old()
-{
-    return CACHE::path_root() +  "favorite.xml";
-}
 
 
 // 外部板設定ファイル( navi2ch 互換 )
@@ -151,11 +132,6 @@ std::string CACHE::path_usrcmd()
     return CACHE::path_root() +  "usrcmd.xml";
 }
 
-std::string CACHE::path_usrcmd_old()
-{
-    return CACHE::path_root() +  "usrcmd.txt";
-}
-
 
 // リンクフィルタ設定ファイル
 std::string CACHE::path_linkfilter()
@@ -507,7 +483,7 @@ std::string CACHE::path_aahistory()
 //
 // テーマのルートパス
 //
-const std::string CACHE::path_theme_root()
+std::string CACHE::path_theme_root()
 {
     return CACHE::path_root() + "theme/";
 }
@@ -515,7 +491,7 @@ const std::string CACHE::path_theme_root()
 //
 // アイコンテーマのルートパス
 //
-const std::string CACHE::path_theme_icon_root()
+std::string CACHE::path_theme_icon_root()
 {
     return CACHE::path_theme_root() + "icons/";
 }
@@ -539,24 +515,6 @@ std::string CACHE::path_reshtml()
 }
 
 
-//
-// css (旧バージョンとの互換性のため)
-//
-std::string CACHE::path_css_old()
-{
-    return CACHE::path_root() +  "jd.css";
-}
-
-
-//
-// res.html (旧バージョンとの互換性のため)
-//
-std::string CACHE::path_reshtml_old()
-{
-    return CACHE::path_root() +  "Res.html";
-}
-
-
 //
 // キャッシュのルートディレクトリをmkdir
 //
@@ -1006,25 +964,45 @@ void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
 {
     if( type == FILE_TYPE_ALL ) return;
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+    Glib::RefPtr< Gtk::FileFilter > filter = Gtk::FileFilter::create();
+#else
     Gtk::FileFilter filter;
+#endif
     switch( type ) 
     {
         case FILE_TYPE_TEXT:
+#if GTKMM_CHECK_VERSION(3,0,0)
+            filter->set_name( "全てのテキストファイル" );
+            filter->add_mime_type( "text/plain" );
+#else
             filter.set_name( "全てのテキストファイル" );
             filter.add_mime_type( "text/plain" );
+#endif
             diag.add_filter( filter );
             break;
 
         case FILE_TYPE_DAT:
+#if GTKMM_CHECK_VERSION(3,0,0)
+            filter->set_name( "全てのDATファイル" );
+            filter->add_pattern( "*.dat" );
+#else
             filter.set_name( "全てのDATファイル" );
             filter.add_pattern( "*.dat" );
+#endif
             diag.add_filter( filter );
             break;
     }
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+    Glib::RefPtr< Gtk::FileFilter > all = Gtk::FileFilter::create();
+    all->set_name( "全てのファイル" );
+    all->add_pattern( "*" );
+#else
     Gtk::FileFilter all;
     all.set_name( "全てのファイル" );
     all.add_pattern( "*" );
+#endif
     diag.add_filter( all );
 }
 
@@ -1184,7 +1162,7 @@ guint64 CACHE::get_dirsize( const std::string& dir )
 
 // 相対パスから絶対パスを取得してファイルが存在すれば絶対パスを返す
 // ファイルが存在しない場合は std::string() を返す
-const std::string CACHE::get_realpath( const std::string& path )
+std::string CACHE::get_realpath( const std::string& path )
 {
     std::string path_real;
 
