@@ -49,6 +49,7 @@ void AboutConfig::pack_widgets()
     m_label.set_text( "動作保証外です。高度な設定を変更するとJDimが誤作動する場合があります。" );
 
     m_liststore = Gtk::ListStore::create( m_columns );
+    m_treeview.property_fixed_height_mode() = true;
     m_treeview.set_model( m_liststore );
     m_treeview.set_size_request( 700, 400 );
     m_treeview.signal_row_activated().connect( sigc::mem_fun( *this, &AboutConfig::slot_row_activated ) );
@@ -62,6 +63,8 @@ void AboutConfig::pack_widgets()
     if( cell ) column->set_cell_data_func( *cell, sigc::mem_fun( *this, &AboutConfig::slot_cell_data ) );
 
     column = Gtk::manage( new Gtk::TreeViewColumn( "値", m_columns.m_col_value ) );
+    column->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED );
+    column->set_resizable( true );
     m_treeview.append_column( *column );
     cell = column->get_first_cell();
     if( cell ) column->set_cell_data_func( *cell, sigc::mem_fun( *this, &AboutConfig::slot_cell_data ) );
@@ -74,6 +77,9 @@ void AboutConfig::pack_widgets()
     get_vbox()->pack_start( m_scrollwin );
 
     set_title( "about:config 高度な設定" );
+#if GTKMM_CHECK_VERSION(3,0,0)
+    set_default_size_ratio( 0.666 );
+#endif
     show_all_children();
 
     append_rows();
@@ -216,6 +222,7 @@ void AboutConfig::append_rows()
     append_row( "デフォルトで連鎖あぼーん", get_confitem()->abone_chain, CONF_ABONE_CHAIN );
     append_row( "書き込み履歴のあるスレを削除する時にダイアログを表示", get_confitem()->show_del_written_thread_diag, CONF_SHOW_DEL_WRITTEN_THREAD_DIAG );
     append_row( "スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )", get_confitem()->delete_img_in_thread, CONF_DELETE_IMG_IN_THREAD );
+    append_row( "最大表示可能レス数", get_confitem()->max_resnumber, CONF_MAX_RESNUMBER );
 
     // 書き込みウィンドウ
     append_row( "" );
@@ -360,7 +367,7 @@ void AboutConfig::set_value( Gtk::TreeModel::Row& row, const std::string& value
 }
 
 
-void AboutConfig::set_value( Gtk::TreeModel::Row& row, const int& value )
+void AboutConfig::set_value( Gtk::TreeModel::Row& row, const int value )
 {
     row[ m_columns.m_col_value ] = MISC::itostr( value );
 
@@ -370,7 +377,7 @@ void AboutConfig::set_value( Gtk::TreeModel::Row& row, const int& value )
 }
 
 
-void AboutConfig::set_value( Gtk::TreeModel::Row& row, const bool& value )
+void AboutConfig::set_value( Gtk::TreeModel::Row& row, const bool value )
 {
     if( value ) row[ m_columns.m_col_value ] = "はい";
     else row[ m_columns.m_col_value ] = "いいえ";
