@@ -66,31 +66,14 @@ ConfigItems::ConfigItems()
     fontname.resize( FONT_NUM );
 }
 
-ConfigItems::~ConfigItems() noexcept
-{}
+ConfigItems::~ConfigItems() noexcept = default;
+
 
 // 設定読み込み
 bool ConfigItems::load( const bool restore )
 {
-    std::string path_conf;
-
     // restoreモード
-    if( restore )
-    {
-        path_conf = CACHE::path_conf_bkup();
-    }
-    else
-    {
-        path_conf = CACHE::path_conf();
-
-        // 新設定ファイルが無く、かつキャッシュディレクトリが存在していたら旧ファイルから設定を引き継ぐ
-        if( CACHE::file_exists( path_conf ) != CACHE::EXIST_FILE
-            && CACHE::file_exists( CACHE::path_root() ) == CACHE::EXIST_DIR
-            && CACHE::file_exists( CACHE::path_conf_old() ) == CACHE::EXIST_FILE ){
-
-                path_conf = CACHE::path_conf_old();
-        }
-    }
+    const std::string path_conf = restore ? CACHE::path_conf_bkup() : CACHE::path_conf();
 
     JDLIB::ConfLoader cf( path_conf, std::string() );
 
@@ -291,6 +274,9 @@ bool ConfigItems::load( const bool restore )
     menu_search_web = cf.get_option_str( "menu_search_web", CONF_MENU_SEARCH_WEB );
     url_search_web = cf.get_option_str( "url_search_web", CONF_URL_SEARCH_WEB );
 
+    // 書き込みビューでGTKテーマの設定を使用するか (GTK3版のみ)
+    use_message_gtktheme = cf.get_option_bool( "use_message_gtktheme", CONF_USE_MESSAGE_GTKTHEME );
+
     // ツリービューでgtkrcの設定を使用するか
     use_tree_gtkrc = cf.get_option_bool( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
 
@@ -597,6 +583,9 @@ bool ConfigItems::load( const bool restore )
     // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
     delete_img_in_thread = cf.get_option_int( "delete_img_in_thread", CONF_DELETE_IMG_IN_THREAD, 0, 2 );
 
+    //最大表示可能レス数
+    max_resnumber = cf.get_option_int( "max_resnumber", CONF_MAX_RESNUMBER, 1, std::numeric_limits< int >::max() - 1 );
+
     // FIFOの作成などにエラーがあったらダイアログを表示する
     show_diag_fifo_error = cf.get_option_bool( "show_diag_fifo_error", CONF_SHOW_DIAG_FIFO_ERROR );
 
@@ -647,7 +636,6 @@ bool ConfigItems::load( const bool restore )
 void ConfigItems::save()
 {
     save_impl( CACHE::path_conf() );
-    if( CACHE::file_exists( CACHE::path_conf_old() ) == CACHE::EXIST_FILE ) save_impl( CACHE::path_conf_old() );
 }
 
 
@@ -803,6 +791,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_back_board", str_color[ COLOR_BACK_BOARD ] );
     cf.update( "cl_back_board_even", str_color[ COLOR_BACK_BOARD_EVEN ] );
 
+    cf.update( "use_message_gtktheme", use_message_gtktheme );
     cf.update( "use_tree_gtkrc", use_tree_gtkrc );
     cf.update( "use_select_gtkrc", use_select_gtkrc );
 
@@ -945,6 +934,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_machi_offlaw", use_machi_offlaw );
     cf.update( "show_del_written_thread_diag", show_del_written_thread_diag );
     cf.update( "delete_img_in_thread", delete_img_in_thread );
+    cf.update( "max_resnumber", max_resnumber );
     cf.update( "show_diag_fifo_error", show_diag_fifo_error );
     cf.update( "save_session", save_session );
 
