@@ -19,7 +19,6 @@ CONFIG::ConfigItems* instance_confitem_bkup = NULL;
 
 CONFIG::ConfigItems* CONFIG::get_confitem()
 {
-    if( ! instance_confitem ) instance_confitem = new CONFIG::ConfigItems();
     return instance_confitem;
 }
 
@@ -36,6 +35,7 @@ void CONFIG::delete_confitem()
 
 bool CONFIG::load_conf()
 {
+    if( ! instance_confitem ) instance_confitem = new CONFIG::ConfigItems();
     return get_confitem()->load();
 }
 
@@ -88,6 +88,9 @@ void CONFIG::set_color( const int id, const std::string& color )
 
 void CONFIG::reset_colors(){ get_confitem()->reset_colors(); }
 
+bool CONFIG::get_use_message_gtktheme() { return get_confitem()->use_message_gtktheme; }
+void CONFIG::set_use_message_gtktheme( const bool use ) { get_confitem()->use_message_gtktheme = use; }
+
 bool CONFIG::get_use_tree_gtkrc(){ return get_confitem()->use_tree_gtkrc; }
 void CONFIG::set_use_tree_gtkrc( const bool use ){ get_confitem()->use_tree_gtkrc = use; }
 
@@ -134,11 +137,11 @@ void CONFIG::reset_fonts(){ get_confitem()->reset_fonts(); }
 bool CONFIG::get_aafont_enabled(){ return get_confitem()->aafont_enabled; }
 
 
-const std::string CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix + get_confitem()->ref_prefix_space_str; }
+std::string CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix + get_confitem()->ref_prefix_space_str; }
 int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
 
 // レスにアスキーアートがあると判定する正規表現
-const std::string CONFIG::get_regex_res_aa(){
+std::string CONFIG::get_regex_res_aa(){
     std::string str = get_confitem()->regex_res_aa;
     int size = str.size();
 
@@ -326,10 +329,10 @@ bool CONFIG::get_open_one_category(){ return get_confitem()->open_one_category;
 bool CONFIG::get_open_one_favorite(){ return get_confitem()->open_one_favorite; }
 
 // デフォルトの書き込み名
-const std::string CONFIG::get_write_name(){ return get_confitem()->write_name; }
+std::string CONFIG::get_write_name(){ return get_confitem()->write_name; }
 
 // デフォルトのメールアドレス
-const std::string CONFIG::get_write_mail(){ return get_confitem()->write_mail; }
+std::string CONFIG::get_write_mail(){ return get_confitem()->write_mail; }
 
 bool CONFIG::get_always_write_ok() { return get_confitem()->always_write_ok; }
 void CONFIG::set_always_write_ok( const bool write_ok ){ get_confitem()->always_write_ok = write_ok; }
@@ -595,6 +598,11 @@ void CONFIG::set_del_written_thread_diag( const bool set ){ get_confitem()->show
 int CONFIG::get_delete_img_in_thread(){ return get_confitem()->delete_img_in_thread; }
 void CONFIG::set_delete_img_in_thread( const int set ){ get_confitem()->delete_img_in_thread = set; }
 
+//最大表示可能レス数
+int CONFIG::get_max_resnumber(){ return get_confitem()->max_resnumber; }
+void CONFIG::set_max_resnumber( const int set ){ get_confitem()->max_resnumber = set; }
+
+
 // FIFOの作成などにエラーがあったらダイアログを表示する
 bool CONFIG::get_show_diag_fifo_error(){ return get_confitem()->show_diag_fifo_error; }
 void CONFIG::set_show_diag_fifo_error( const bool set ){ get_confitem()->show_diag_fifo_error = set; }
