@@ -137,11 +137,59 @@ bool CONTROL::is_ascii( const guint keysym )
 }
 
 
+#if GTKMM_CHECK_VERSION(3,6,0)
+static void slot_set_menu_motion( Gtk::Widget& widget )
+{
+    const auto item = dynamic_cast< Gtk::MenuItem* >( &widget );
+
+    auto* const label = dynamic_cast< Gtk::AccelLabel* >( item->get_child() );
+    if( label ) {
+#ifdef _DEBUG
+        std::cout << label->get_text() << std::endl;
+#endif
+        const int id = CONTROL::get_id( label->get_text() );
+        if( id != CONTROL::None ) {
+            const std::string str_label = CONTROL::get_label_with_mnemonic( id );
+            std::string str_motions;
+
+            // CONTROL::get_str_motions()を参考に別個対応のidを処理する
+            if( id == CONTROL::PreferenceArticle
+                || id == CONTROL::PreferenceBoard
+                || id == CONTROL::PreferenceImage ) {
+                label->set_accel( GDK_KEY_p, Gdk::CONTROL_MASK | Gdk::SHIFT_MASK );
+                str_motions = CONTROL::get_str_mousemotions( CONTROL::PreferenceView );
+            }
+            else if( id == CONTROL::SaveDat ) {
+                label->set_accel( GDK_KEY_s, Gdk::CONTROL_MASK );
+                str_motions = CONTROL::get_str_mousemotions( CONTROL::Save );
+            }
+            else {
+                const auto key = CONTROL::get_accelkey( id );
+                if( !key.is_null() ) {
+                    label->set_accel( key.get_key(), key.get_mod() );
+                }
+                str_motions = CONTROL::get_str_mousemotions( id );
+            }
+
+            label->set_text_with_mnemonic( str_label + ( str_motions.empty() ? "" : "\t" + str_motions ) );
+        }
+    }
+
+    if( item->has_submenu() ) {
+        CONTROL::set_menu_motion( item->get_submenu() );
+    }
+}
+#endif // GTKMM_CHECK_VERSION(3,6,0)
+
+
 // メニューにショートカットキーやマウスジェスチャを表示
 void CONTROL::set_menu_motion( Gtk::Menu* menu )
 {
     if( !menu ) return;
 
+#if GTKMM_CHECK_VERSION(3,6,0)
+    menu->foreach( &slot_set_menu_motion );
+#else
     menu->foreach( []( Gtk::Widget& w ) {
         auto* const item = dynamic_cast< Gtk::MenuItem* >( &w );
 
@@ -158,6 +206,10 @@ void CONTROL::set_menu_motion( Gtk::Menu* menu )
                 std::string str_label = CONTROL::get_label_with_mnemonic( id );
                 std::string str_motions = CONTROL::get_str_motions( id );
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+                // Gtk::MenuItemにGtk::HBoxを追加する方法は動作しなくなった
+                label->set_text_with_mnemonic( str_label + ( str_motions.empty() ? "" : "\t" + str_motions ) );
+#else
                 item->remove();
                 Gtk::Label *label = Gtk::manage( new Gtk::Label( str_label + ( str_motions.empty() ? "" : "  " ), true ) );
                 Gtk::Label *label_motion = Gtk::manage( new Gtk::Label( str_motions ) );
@@ -167,11 +219,13 @@ void CONTROL::set_menu_motion( Gtk::Menu* menu )
                 box->pack_end( *label_motion, Gtk::PACK_SHRINK );
                 item->add( *box );
                 box->show_all();
+#endif
             }
         }
 
         if( item->has_submenu() ) CONTROL::set_menu_motion( item->get_submenu() );
     } );
+#endif // GTKMM_CHECK_VERSION(3,6,0)
 }
 
 
@@ -195,7 +249,7 @@ int CONTROL::get_mode( const int id )
 
 // 操作モードIDからモード名取得
 // 例えば mode == CONTROL::MODE_COMMON の時は "共通" を返す
-const std::string CONTROL::get_mode_label( const int mode )
+std::string CONTROL::get_mode_label( const int mode )
 {
     if( mode < CONTROL::MODE_START || mode > MODE_END ) return std::string();
 
@@ -235,7 +289,7 @@ guint CONTROL::get_keysym( const std::string& keyname )
 
 // keysymからキー名を取得
 // 例えば keysym == GDK_space の時は "Space"  を返す
-const std::string CONTROL::get_keyname( const guint keysym )
+std::string CONTROL::get_keyname( const guint keysym )
 {
 #ifdef _DEBUG
     std::cout << "CONTROL::get_keyname sym = " << keysym;
@@ -282,7 +336,7 @@ int CONTROL::get_id( const std::string& name )
 
 // IDから操作名取得
 // 例えば id == CONTROL::Up の時は "Up" を返す
-const std::string CONTROL::get_name( const int id )
+std::string CONTROL::get_name( const int id )
 {
     if( id < CONTROL::COMMONMOTION || id >=  CONTROL::CONTROL_END ) return std::string();
 
@@ -292,7 +346,7 @@ const std::string CONTROL::get_name( const int id )
 
 // IDからラベル取得
 // 例えば id == CONTROL::Up の時は "上移動" を返す
-const std::string CONTROL::get_label( const int id )
+std::string CONTROL::get_label( const int id )
 {
     if( id < CONTROL::COMMONMOTION || id >=  CONTROL::CONTROL_END ) return std::string();
 
@@ -302,12 +356,10 @@ const std::string CONTROL::get_label( const int id )
 
 // IDからショートカットを付けたラベルを取得
 // 例えば id == CONTROL::Save の時は "名前を付けて保存(_S)..." を返す
-const std::string CONTROL::get_label_with_mnemonic( const int id )
+std::string CONTROL::get_label_with_mnemonic( const int id )
 {
-    unsigned int pos;
-
     std::string label = CONTROL::get_label ( id );
-    pos = label.find( "...", 0);
+    const auto pos = label.find( "...", 0);
     if ( pos != std::string::npos )
     {
         switch ( id )
@@ -486,7 +538,7 @@ const std::string CONTROL::get_label_with_mnemonic( const int id )
 
 
 // IDからキーボードとマウスジェスチャの両方を取得
-const std::string CONTROL::get_str_motions( const int id )
+std::string CONTROL::get_str_motions( const int id )
 {
     int ctl = id;
 
@@ -516,7 +568,7 @@ const std::string CONTROL::get_str_motions( const int id )
 
 
 // IDからラベルと操作の両方を取得
-const std::string CONTROL::get_label_motions( const int id )
+std::string CONTROL::get_label_motions( const int id )
 {
     std::string motion = CONTROL::get_str_motions( id );
     return CONTROL::get_label( id ) + ( motion.empty() ? "" :  "  " ) + motion;
@@ -686,14 +738,14 @@ void CONTROL::restore_keyconfig()
 
 
 // IDからキーボード操作を取得
-const std::string CONTROL::get_str_keymotions( const int id )
+std::string CONTROL::get_str_keymotions( const int id )
 {
     return CONTROL::get_keyconfig()->get_str_motions( id );
 }
 
 
 // IDからデフォルトキーボード操作を取得
-const std::string CONTROL::get_default_keymotions( const int id )
+std::string CONTROL::get_default_keymotions( const int id )
 {
     return CONTROL::get_keyconfig()->get_default_motions( id );
 }
@@ -714,7 +766,7 @@ bool CONTROL::remove_keymotions( const int id )
 
 
 // キーボード操作が重複していないか
-const std::vector< int > CONTROL::check_key_conflict( const int mode, const std::string& str_motion )
+std::vector< int > CONTROL::check_key_conflict( const int mode, const std::string& str_motion )
 {
     return CONTROL::get_keyconfig()->check_conflict( mode, str_motion );
 }
@@ -794,14 +846,14 @@ void CONTROL::restore_mouseconfig()
 
 
 // IDからマウスジェスチャを取得
-const std::string CONTROL::get_str_mousemotions( const int id )
+std::string CONTROL::get_str_mousemotions( const int id )
 {
     return convert_mouse_motions( CONTROL::get_mouseconfig()->get_str_motions( id ) );
 }
 
 
 // IDからデフォルトマウスジェスチャを取得
-const std::string CONTROL::get_default_mousemotions( const int id )
+std::string CONTROL::get_default_mousemotions( const int id )
 {
     return convert_mouse_motions( CONTROL::get_mouseconfig()->get_default_motions( id ) );
 }
@@ -823,7 +875,7 @@ bool CONTROL::remove_mousemotions( const int id )
 
 
 // マウスジェスチャが重複していないか
-const std::vector< int > CONTROL::check_mouse_conflict( const int mode, const std::string& str_motion )
+std::vector< int > CONTROL::check_mouse_conflict( const int mode, const std::string& str_motion )
 {
     const std::string motion = convert_mouse_motions_reverse( str_motion );
     return CONTROL::get_mouseconfig()->check_conflict( mode, motion );
@@ -849,14 +901,14 @@ void CONTROL::restore_buttonconfig()
 
 
 // IDからボタン設定を取得
-const std::string CONTROL::get_str_buttonmotions( const int id )
+std::string CONTROL::get_str_buttonmotions( const int id )
 {
     return CONTROL::get_buttonconfig()->get_str_motions( id );
 }
 
 
 // IDからデフォルトボタン設定を取得
-const std::string CONTROL::get_default_buttonmotions( const int id )
+std::string CONTROL::get_default_buttonmotions( const int id )
 {
     return CONTROL::get_buttonconfig()->get_default_motions( id );
 }
@@ -876,7 +928,7 @@ bool CONTROL::remove_buttonmotions( const int id )
 
 
     // ボタンが重複していないか
-const std::vector< int > CONTROL::check_button_conflict( const int mode, const std::string& str_motion )
+std::vector< int > CONTROL::check_button_conflict( const int mode, const std::string& str_motion )
 {
     return CONTROL::get_buttonconfig()->check_conflict( mode, str_motion );
 }
