@@ -205,7 +205,7 @@ bool InputDiag::on_motion_notify_event( GdkEventMotion* event )
 }
 
 
-const std::string InputDiag::get_key_label()
+std::string InputDiag::get_key_label()
 {
     std::string label;
 
@@ -225,7 +225,7 @@ const std::string InputDiag::get_key_label()
 
 
 
-const std::string InputDiag::get_mouse_label()
+std::string InputDiag::get_mouse_label()
 {
     std::string label;
 
@@ -244,7 +244,7 @@ const std::string InputDiag::get_mouse_label()
 }
 
 
-const std::string InputDiag::get_button_label()
+std::string InputDiag::get_button_label()
 {
     std::string label;
 
@@ -301,11 +301,11 @@ MouseKeyDiag::MouseKeyDiag( Gtk::Window* parent, const std::string& url,
     m_vbuttonbox.set_layout( Gtk::BUTTONBOX_START );
     m_vbuttonbox.set_spacing( 4 );
 
-    m_hbox.pack_start( m_scrollwin, Gtk::PACK_SHRINK );
+    m_hbox.pack_start( m_scrollwin, Gtk::PACK_EXPAND_WIDGET );
     m_hbox.pack_start( m_vbuttonbox, Gtk::PACK_SHRINK );
 
     get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label );
+    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
     get_vbox()->pack_start( m_hbox );
 
     show_all_children();
@@ -335,7 +335,7 @@ Gtk::TreeModel::Row MouseKeyDiag::append_row( const std::string& motion )
 }
 
 
-const std::string MouseKeyDiag::get_str_motions()
+std::string MouseKeyDiag::get_str_motions()
 {
     std::string str_motions;
 
@@ -357,7 +357,7 @@ const std::string MouseKeyDiag::get_str_motions()
 //
 // 入力ダイアログを表示
 //
-const std::string MouseKeyDiag::show_inputdiag( bool is_append )
+std::string MouseKeyDiag::show_inputdiag( bool is_append )
 {
     std::string str_motion;
 
@@ -543,6 +543,9 @@ MouseKeyPref::MouseKeyPref( Gtk::Window* parent, const std::string& url, const s
     get_vbox()->pack_start( m_scrollwin );
     get_vbox()->pack_start( m_hbox, Gtk::PACK_SHRINK );
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+    set_default_size_ratio( 0.666 );
+#endif
     show_all_children();
     set_title( target + "設定" );
 }
