@@ -85,7 +85,7 @@ void Css_Manager::clear_property( CSS_PROPERTY* css )
 //
 // ユーザ設定の色取得
 // 
-std::string Css_Manager::get_color( int colorid )
+std::string Css_Manager::get_color( int colorid ) const
 {
     colorid -= USRCOLOR_BASE;
     return m_colors[ colorid ];
@@ -95,11 +95,11 @@ std::string Css_Manager::get_color( int colorid )
 //
 // クラス名からID取得
 //
-int Css_Manager::get_classid( const std::string& classname )
+int Css_Manager::get_classid( const std::string& classname ) const
 {
     int id = 0;
 
-    std::list< std::string >::iterator it = m_css_class.begin();
+    std::list< std::string >::const_iterator it = m_css_class.begin();
     for( ; it != m_css_class.end(); ++it, ++id ) if( ( *it ) == classname ) return id;
 
     return -1;
@@ -218,11 +218,7 @@ bool Css_Manager::read_css()
 #endif    
 
     std::string css_data;
-    if( ! CACHE::load_rawdata( css_file, css_data ) ){
-
-        // 旧バージョンとの互換性のため
-        if( ! CACHE::load_rawdata( CACHE::path_css_old(), css_data ) ) return false;
-    }
+    if( ! CACHE::load_rawdata( css_file, css_data ) ) return false;
 
 #ifdef _DEBUG
     std::cout << "css : \n" << css_data << "--------------\n\n";
@@ -546,7 +542,7 @@ void Css_Manager::set_property( const std::string& classname, const CSS_PROPERTY
 //
 // 文字の高さを与えてemをセット
 //
-void Css_Manager::set_size( CSS_PROPERTY* css, double height )
+void Css_Manager::set_size( CSS_PROPERTY* css, double height ) const
 {
     if( ! css ) return;
     if( ! height ) return;
@@ -665,7 +661,7 @@ DOM* Css_Manager::create_textnode( const char* text )
 #endif
 
     DOM* tmpdom = create_domnode( DOMNODE_TEXT );
-    tmpdom->chardat = ( char* ) m_heap.heap_alloc( lng );
+    tmpdom->chardat = ( char* ) m_heap.heap_alloc( lng + 1 );
     strncpy( tmpdom->chardat, text, lng );
 
     return tmpdom;
@@ -719,11 +715,7 @@ bool Css_Manager::read_html()
 #endif    
 
     std::string html;
-    if( ! CACHE::load_rawdata( htmlfile, html ) ){
-
-        // 旧バージョンとの互換性のため
-        if( ! CACHE::load_rawdata( CACHE::path_reshtml_old(), html ) ) return false;
-    }
+    if( ! CACHE::load_rawdata( htmlfile, html ) ) return false;
 
 #ifdef _DEBUG
     std::cout << "html : \n" << html << "--------------\n\n";
