@@ -137,7 +137,7 @@ bool ArticleBase::equal( const std::string& datbase, const std::string& id )
 //
 // 移転する前のオリジナルのURL
 //
-const std::string ArticleBase::get_org_url()
+std::string ArticleBase::get_org_url()
 {
     std::string newhost = MISC::get_hostname( m_url );
     return m_org_host + m_url.substr( newhost.length() );
@@ -185,7 +185,7 @@ NODE* ArticleBase::res_header( int number )
 //
 // number番の名前
 //
-const std::string ArticleBase::get_name( int number )
+std::string ArticleBase::get_name( int number )
 {
     return get_nodetree()->get_name( number );
 }
@@ -213,7 +213,7 @@ std::list< int > ArticleBase::get_res_name( const std::string& name )
 // number番のレスの時刻を文字列で取得
 // 内部で regex　を使っているので遅い
 //
-const std::string ArticleBase::get_time_str( int number )
+std::string ArticleBase::get_time_str( int number )
 {
     return get_nodetree()->get_time_str( number );
 }
@@ -222,7 +222,7 @@ const std::string ArticleBase::get_time_str( int number )
 //
 // number番の発言者ID
 //
-const std::string ArticleBase::get_id_name( int number )
+std::string ArticleBase::get_id_name( int number )
 {
     return get_nodetree()->get_id_name( number );
 }
@@ -322,7 +322,7 @@ std::list< int > ArticleBase::get_res_with_url()
 //
 // mode_or == true なら OR抽出
 //
-const std::list< int > ArticleBase::get_res_query( const std::string& query, const bool mode_or )
+std::list< int > ArticleBase::get_res_query( const std::string& query, const bool mode_or )
 {
     if( empty() ){ std::list< int > tmp; return tmp; }
 
@@ -334,7 +334,7 @@ const std::list< int > ArticleBase::get_res_query( const std::string& query, con
 // number番のレスの文字列を返す
 // ref == true なら先頭に ">" を付ける        
 //
-const std::string ArticleBase::get_res_str( int number, bool ref )
+std::string ArticleBase::get_res_str( int number, bool ref )
 {
     return get_nodetree()->get_res_str( number, ref );
 }
@@ -343,7 +343,7 @@ const std::string ArticleBase::get_res_str( int number, bool ref )
 //
 // number　番のレスの生文字列を返す
 //
-const std::string ArticleBase::get_raw_res_str( int number )
+std::string ArticleBase::get_raw_res_str( int number )
 {
     return get_nodetree()->get_raw_res_str( number );
 }
@@ -424,7 +424,7 @@ void ArticleBase::set_org_host( const std::string& host )
 //
 // access_time を 文字列に変換して返す
 //
-const std::string ArticleBase::get_access_time_str()
+std::string ArticleBase::get_access_time_str()
 {
     return MISC::timevaltostr( m_access_time );
 }
@@ -570,11 +570,7 @@ void ArticleBase::update_writetime()
 //
 int ArticleBase::get_num_posted()
 {
-    if( ! m_vec_posted.size() ) return 0;
-
-    int ret = 0;
-    for( int i = 1; i < MAX_RESNUMBER; ++i ) if( is_posted( i ) ) ++ret;
-    return ret;
+    return m_posts.size();
 }
 
 
@@ -662,7 +658,7 @@ void ArticleBase::update_abone()
     // nodetreeが作られていないときは更新しない
     if( ! m_nodetree ) return;
 
-    get_nodetree()->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
+    get_nodetree()->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_abone_reses,
                                      m_abone_transparent, m_abone_chain, m_abone_age, m_abone_board, m_abone_global );
 
     get_nodetree()->update_abone_all();
@@ -704,11 +700,13 @@ void ArticleBase::reset_abone( const std::list< std::string >& ids,
 
     if( vec_abone_res.size() ){
 
-        if( ! m_vec_abone_res.size() ) m_vec_abone_res.resize( MAX_RESNUMBER );
-
         for( int i = 1; i <= MIN( m_number_load, (int)vec_abone_res.size() ) ; ++i ){
-            if( vec_abone_res[ i ] ) m_vec_abone_res[ i ] = true;
-            else m_vec_abone_res[ i ] = false;
+            if( vec_abone_res[ i ] ) {
+                m_abone_reses.insert( i );
+            }
+            else {
+                m_abone_reses.erase( i );
+            }
         }
     }
     
@@ -795,15 +793,18 @@ void ArticleBase::set_abone_res( const int num_from, const int num_to, const boo
 {
     if( empty() ) return;
     if( num_from > num_to ) return;
-    if( num_from <= 0 || num_to >= MAX_RESNUMBER ) return;
+    if( num_from <= 0 || num_to > CONFIG::get_max_resnumber() ) return;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::set_abone_res num_from = " << num_from << " num_to = " << num_to << " set = " << set << std::endl;
 #endif    
 
-    if( ! m_vec_abone_res.size() ) m_vec_abone_res.resize( MAX_RESNUMBER );
-
-    for( int i = num_from; i <= num_to; ++i ) m_vec_abone_res[ i ] = set;
+    if( set ) {
+        for( int i = num_from; i <= num_to; ++i ) m_abone_reses.insert( i );
+    }
+    else {
+        for( int i = num_from; i <= num_to; ++i ) m_abone_reses.erase( i );
+    }
 
     update_abone();
 
@@ -892,11 +893,7 @@ void ArticleBase::set_abone_global( const bool set )
 //
 int ArticleBase::get_num_bookmark()
 {
-    if( ! m_vec_bookmark.size() ) return 0;
-
-    int ret = 0;
-    for( int i = 1; i < MAX_RESNUMBER; ++i ) if( is_bookmarked( i ) ) ++ret;
-    return ret;
+    return m_bookmarks.size();
 }
 
 
@@ -908,11 +905,9 @@ bool ArticleBase::is_bookmarked( const int number )
     if( number <= 0 || number > m_number_load ) return false;
 
     // まだnodetreeが作られてなくてブックマークの情報が得られてないのでnodetreeを作って情報取得
-    if( ! m_vec_bookmark.size() ) get_nodetree();
+    if( m_bookmarks.empty() ) get_nodetree();
 
-    if( ! m_vec_bookmark.size() ) return false;
-
-    return ( m_vec_bookmark[ number ] );
+    return ( m_bookmarks.find( number ) != m_bookmarks.end() );
 }
 
 
@@ -921,13 +916,16 @@ bool ArticleBase::is_bookmarked( const int number )
 //
 void ArticleBase::set_bookmark( const int number, const bool set )
 {
-    if( ! m_vec_bookmark.size() ) get_nodetree();
-    if( number <= 0 || number > MAX_RESNUMBER ) return;
-
-    if( ! m_vec_bookmark.size() ) m_vec_bookmark.resize( MAX_RESNUMBER );
+    if( m_bookmarks.empty() ) get_nodetree();
+    if( number <= 0 || number > CONFIG::get_max_resnumber() ) return;
 
     m_save_info = true;
-    m_vec_bookmark[ number ] = set;
+    if( set ) {
+        m_bookmarks.insert( number );
+    }
+    else {
+        m_bookmarks.erase( number );
+    }
 }
 
 
@@ -939,11 +937,9 @@ bool ArticleBase::is_posted( const int number )
     if( number <= 0 || number > m_number_load ) return false;
 
     // まだnodetreeが作られてなくて情報が得られてないのでnodetreeを作って情報取得
-    if( ! m_vec_posted.size() ) get_nodetree();
+    if( m_posts.empty() ) get_nodetree();
 
-    if( ! m_vec_posted.size() ) return false;
-
-    return ( m_vec_posted[ number ] );
+    return ( m_posts.find( number ) != m_posts.end() );
 }
 
 
@@ -960,12 +956,15 @@ void ArticleBase::set_posted( const int number, const bool set )
     if( number <= 0 || number > m_number_load ) return;
 
     // まだnodetreeが作られてなくて情報が得られてないのでnodetreeを作って情報取得
-    if( ! m_vec_posted.size() ) get_nodetree();
-
-    if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+    if( m_posts.empty() ) get_nodetree();
 
     m_save_info = true;
-    m_vec_posted[ number ] = set;
+    if( set ) {
+        m_posts.insert( number );
+    }
+    else {
+        m_posts.erase( number );
+    }
 
     // nodetreeに情報反映
     m_nodetree->set_posted( number, set );
@@ -979,14 +978,14 @@ void ArticleBase::clear_post_history()
     if( ! is_cached() ) return;
 
     read_info();
-    if( m_vec_posted.size() || m_write_time.tv_sec || m_write_time.tv_usec ){
+    if( !m_posts.empty() || m_write_time.tv_sec || m_write_time.tv_usec ){
 
 #ifdef _DEBUG
-        std::cout << "ArticleBase::clear_post_history size = " << m_vec_posted.size()
+        std::cout << "ArticleBase::clear_post_history size = " << m_posts.size()
                   << " time = " << m_write_time_date
                   << " subject = " << m_subject << std::endl;
 #endif
-        m_vec_posted.clear();
+        m_posts.clear();
         memset( &m_write_time, 0, sizeof( struct timeval ) );
         m_write_time_date = std::string();
 
@@ -1024,11 +1023,11 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
         assert( m_nodetree );
 
         // あぼーん情報のコピー
-        m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
+        m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_abone_reses,
                                      m_abone_transparent, m_abone_chain, m_abone_age, m_abone_board, m_abone_global );
 
         // 書き込み情報のコピー
-        m_nodetree->copy_post_info( m_vec_posted );
+        m_nodetree->copy_post_info( m_posts );
 
         m_nodetree->sig_updated().connect( sigc::mem_fun( *this, &ArticleBase::slot_node_updated ) );
         m_nodetree->sig_finished().connect( sigc::mem_fun( *this, &ArticleBase::slot_load_finished ) );
@@ -1081,7 +1080,7 @@ bool ArticleBase::is_loading() const
 //
 // 更新チェック中か
 //
-bool ArticleBase::is_checking_update()
+bool ArticleBase::is_checking_update() const
 {
     if( ! is_loading() ) return false;
 
@@ -1227,7 +1226,7 @@ void ArticleBase::set_url_pre_article( const std::string& url_pre_article )
 
 
 //
-// url_src で示されるスレの情報をコピー
+// url_src で示されるスレの情報を引き継ぐ
 //
 void ArticleBase::copy_article_info( const std::string& url_src )
 {
@@ -1326,6 +1325,13 @@ void ArticleBase::slot_load_finished()
     // 壊れている
     if( m_nodetree->is_broken() ) m_status |= STATUS_BROKEN;
 
+    // レス数が最大表示可能数以上か
+    if( get_number_load() >= CONFIG::get_max_resnumber() )
+        m_status |= STATUS_OVERFLOW;
+    else {
+        m_status &= ~STATUS_OVERFLOW;
+    }
+
     // 状態が変わっていたら情報保存
     if( old_status != m_status ) m_save_info = true;
 
@@ -1374,17 +1380,22 @@ void ArticleBase::slot_load_finished()
     else m_number_new = 0;
 
     // 書き込み情報
-    if( m_number_new && m_nodetree->get_vec_posted().size() ){
-
-        if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+    const auto& node_posts = m_nodetree->get_posts();
+    if( m_number_new && node_posts.size() ) {
 
+        const auto end = m_posts.end();
+        const auto node_end = node_posts.end();
+        (void)end; // _DEBUGが定義されていないときの警告抑制
         for( int i = m_number_before_load +1; i <= m_number_load; ++i ){
 
-            if( m_nodetree->get_vec_posted()[ i ] ) m_vec_posted[ i ] = true;
-            else m_vec_posted[ i ] = false;
-
+            if( node_posts.find( i ) != node_end ) {
+                m_posts.insert( i );
+            }
+            else {
+                m_posts.erase( i );
+            }
 #ifdef _DEBUG
-            if( m_vec_posted[ i ] ) std::cout << "posted no = " << i << std::endl;
+            if( m_posts.find( i ) != end ) std::cout << "posted no = " << i << std::endl;
 #endif
         }
     }
@@ -1443,7 +1454,7 @@ void ArticleBase::slot_load_finished()
                       << "value = " << value << std::endl;
 #endif
 
-            // このスレは m_url_pre_article の次スレとみなして情報をコピーする
+            // このスレは m_url_pre_article の次スレとみなして情報を引き継ぐ
             if( value >= CONFIG::get_threshold_next() ){
 
 #ifdef _DEBUG
@@ -1711,13 +1722,13 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_write_fixname = false;
         m_write_fixmail = false;
 
-        m_vec_bookmark.clear();
-        m_vec_posted.clear();
+        m_bookmarks.clear();
+        m_posts.clear();
         m_list_abone_id.clear();
         m_list_abone_name.clear();
         m_list_abone_word.clear();
         m_list_abone_regex.clear();
-        m_vec_abone_res.clear();
+        m_abone_reses.clear();
         m_abone_transparent = false;
         m_abone_chain = false;
         m_abone_age = false;
@@ -1822,13 +1833,13 @@ void ArticleBase::read_info()
         // 取得数
         m_number_load = 0;
         GET_INFOVALUE( str_tmp, "load = " );
-        if( ! str_tmp.empty() ) m_number_load = atoi( str_tmp.c_str() );
+        if( ! str_tmp.empty() ) m_number_load = std::stoi( str_tmp );
         m_number_before_load = m_number_load;
 
         // 見た場所
         m_number_seen = 0;
         GET_INFOVALUE( str_tmp, "seen = " );
-        if( ! str_tmp.empty() ) m_number_seen = atoi( str_tmp.c_str() );
+        if( ! str_tmp.empty() ) m_number_seen = std::stoi( str_tmp );
 
         // 更新時間 (time)
         GET_INFOVALUE( m_date_modified, "modified = " );
@@ -1890,14 +1901,11 @@ void ArticleBase::read_info()
         GET_INFOVALUE( str_tmp, "bookmark = " );
         if( ! str_tmp.empty() ){
 
-            if( ! m_vec_bookmark.size() ) m_vec_bookmark.resize( MAX_RESNUMBER );
-
             list_tmp = MISC::split_line( str_tmp );
-            it_tmp = list_tmp.begin();
-            for( ; it_tmp != list_tmp.end(); ++it_tmp ){
-                int number = atoi( (*it_tmp).c_str() );
-                if( !(*it_tmp).empty() ) m_vec_bookmark[ number ] = true;
-                else m_vec_bookmark[ number ] = false;
+            for( const std::string& num_str : list_tmp ) {
+                if( !num_str.empty() ) {
+                    m_bookmarks.insert( std::stoi( num_str ) );
+                }
             }
         }
 
@@ -1920,18 +1928,15 @@ void ArticleBase::read_info()
         if( ! str_tmp.empty() ) m_abone_chain = atoi( str_tmp.c_str() );
 
         // レス番号あぼーん
-        m_vec_abone_res.clear();
+        m_abone_reses.clear();
         GET_INFOVALUE( str_tmp, "aboneres = " );
         if( ! str_tmp.empty() ){
 
-            if( ! m_vec_abone_res.size() ) m_vec_abone_res.resize( MAX_RESNUMBER );
-
             list_tmp = MISC::split_line( str_tmp );
-            it_tmp = list_tmp.begin();
-            for( ; it_tmp != list_tmp.end(); ++it_tmp ){
-                int number = atoi( (*it_tmp).c_str() );
-                if( !(*it_tmp).empty() ) m_vec_abone_res[ number ] = true;
-                else m_vec_abone_res[ number ] = false;
+            for( const std::string& num_str : list_tmp ) {
+                if( !num_str.empty() ) {
+                    m_abone_reses.insert( std::stoi( num_str ) );
+                }
             }
         }
 
@@ -1944,14 +1949,11 @@ void ArticleBase::read_info()
         GET_INFOVALUE( str_tmp, "posted = " );
         if( ! str_tmp.empty() ){
 
-            if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
-
             list_tmp = MISC::split_line( str_tmp );
-            it_tmp = list_tmp.begin();
-            for( ; it_tmp != list_tmp.end(); ++it_tmp ){
-                int number = atoi( (*it_tmp).c_str() );
-                if( !(*it_tmp).empty() ) m_vec_posted[ number ] = true;
-                else m_vec_posted[ number ] = false;
+            for( const std::string& num_str : list_tmp ) {
+                if( !num_str.empty() ) {
+                    m_posts.insert( std::stoi( num_str ) );
+                }
             }
         }
 
@@ -2052,21 +2054,29 @@ void ArticleBase::read_info()
     std::cout << "abone-regex\n"; it = m_list_abone_regex.begin();
     for( ; it != m_list_abone_regex.end(); ++it ) std::cout << (*it) << std::endl;
 
-    if( m_vec_abone_res.size() ){
+    if( !m_abone_reses.empty() ) {
         std::cout << "abone-res =";
-        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_abone_res[ i ] ) std::cout << " " << i;
+        const auto end = m_abone_reses.end();
+        for( int i = 1; i <= m_number_load; ++i ) {
+            if( m_abone_reses.find( i ) != end ) std::cout << ' ' << i;
+        }
+    }
+
+    if( !m_bookmarks.empty() ) {
+        std::cout << "bookmark = ";
+        const auto end = m_bookmarks.end();
+        for( int i = 1; i <= m_number_load; ++i ) {
+            if( m_bookmarks.find( i ) != end ) std::cout << ' ' << i;
+        }
         std::cout << std::endl;
     }
 
-    if( m_vec_bookmark.size() ){
-        std::cout << "bookmark =";
-        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_bookmark[ i ] ) std::cout << " " << i;
-        std::cout << std::endl;
-    }
-
-    if( m_vec_posted.size() ){
+    if( !m_posts.empty() ) {
         std::cout << "posted =";
-        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_posted[ i ] ) std::cout << " " << i;
+        const auto end = m_posts.end();
+        for( int i = 1; i <= m_number_load; ++i ) {
+            if( m_posts.find( i ) != end ) std::cout << ' ' << i;
+        }
         std::cout << std::endl;
     }
 #endif
@@ -2119,20 +2129,29 @@ void ArticleBase::save_info( const bool force )
 
     // レスあぼーん
     std::ostringstream ss_abone_res;
-    if( m_vec_abone_res.size() ){
-        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_abone_res[ i ] ) ss_abone_res << " " << i;
+    if( !m_abone_reses.empty() ) {
+        const auto end = m_abone_reses.end();
+        for( int i = 1; i <= m_number_load; ++i ) {
+            if( m_abone_reses.find( i ) != end ) ss_abone_res << ' ' << i;
+        }
     }
 
     // レスのブックマーク
     std::ostringstream ss_bookmark;
-    if( m_vec_bookmark.size() ){
-        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_bookmark[ i ] ) ss_bookmark << " " << i;
+    if( !m_bookmarks.empty() ) {
+        const auto end = m_bookmarks.end();
+        for( int i = 1; i <= m_number_load; ++i ) {
+            if( m_bookmarks.find( i ) != end ) ss_bookmark << ' ' << i;
+        }
     }
 
     // 書き込み
     std::ostringstream ss_posted;
-    if( m_vec_posted.size() ){
-        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_posted[ i ] ) ss_posted << " " << i;
+    if( !m_posts.empty() ) {
+        const auto end = m_posts.end();
+        for( int i = 1; i <= m_number_load; ++i ) {
+            if( m_posts.find( i ) != end ) ss_posted << ' ' << i;
+        }
     }
 
     std::ostringstream sstr;
