@@ -9,16 +9,17 @@
 #ifndef _ARTICLEBASE_H
 #define _ARTICLEBASE_H
 
-#include <string>
-#include <sys/time.h>
-#include <list>
-#include <vector>
-#include <ctime>
-
 #include "skeleton/lockable.h"
 
 #include "jdlib/constptr.h"
 
+#include <ctime>
+#include <list>
+#include <string>
+#include <sys/time.h>
+#include <unordered_set>
+#include <vector>
+
 namespace DBTREE
 {
     class NodeTreeBase;
@@ -74,7 +75,7 @@ namespace DBTREE
         std::list< std::string > m_list_abone_name; // あぼーんする名前
         std::list< std::string > m_list_abone_word; // あぼーんする文字列
         std::list< std::string > m_list_abone_regex; // あぼーんする正規表現
-        std::vector< char > m_vec_abone_res; // レスあぼーん情報
+        std::unordered_set< int > m_abone_reses; // レスあぼーん情報
         bool m_abone_transparent; // 透明あぼーん
         bool m_abone_chain; // 連鎖あぼーん
         bool m_abone_age; // age ているレスをあぼーん
@@ -85,10 +86,10 @@ namespace DBTREE
         bool m_bookmarked_thread;
 
         // 「レス」のブックマーク
-        std::vector< char > m_vec_bookmark; // ブックマーク判定キャッシュ
+        std::unordered_set< int > m_bookmarks; // ブックマーク判定キャッシュ
 
         // 自分が書き込んだレスか
-        std::vector< char > m_vec_posted;
+        std::unordered_set< int > m_posts;
 
         // HDDにキャッシュされているか
         bool m_cached;
@@ -132,7 +133,7 @@ namespace DBTREE
         void update_datbase( const std::string& datbase );
 
         // 移転する前のオリジナルのURL
-        const std::string get_org_url();
+        std::string get_org_url();
 
         // 移転する前のオリジナルのホスト名
         const std::string& get_org_host() const { return m_org_host; }
@@ -145,7 +146,7 @@ namespace DBTREE
         int get_number_diff() const { return m_number_diff; }
         int get_number_new() const { return m_number_new; }
         int get_number_load() const { return m_number_load; }
-        int get_number_seen() const{  return m_number_seen; }
+        int get_number_seen() const {  return m_number_seen; }
 
         void set_number_max( const int number ){ m_number_max = number; }
 
@@ -159,7 +160,7 @@ namespace DBTREE
         NODE* res_header( int number );
 
         // number番のレスの発言者の名前
-        const std::string get_name( int number );
+        std::string get_name( int number );
 
         // number番の名前の重複数( = 発言数 )
         int get_num_name( int number );
@@ -169,10 +170,10 @@ namespace DBTREE
 
         // number番のレスの時刻を文字列で取得
         // 内部で regex　を使っているので遅い
-        const std::string get_time_str( int number );
+        std::string get_time_str( int number );
 
         // number番のレスの発言者ID( スレIDではなくて名前の横のID )
-        const std::string get_id_name( int number );
+        std::string get_id_name( int number );
 
         // 指定した発言者ID の重複数( = 発言数 )
         // (注) 下の get_num_id_name( int number )と違って検索するので遅い
@@ -206,14 +207,14 @@ namespace DBTREE
 
         // query を含むレス番号をリストにして取得
         // mode_or == true なら OR抽出
-        const std::list< int > get_res_query( const std::string& query, const bool mode_or );
+        std::list< int > get_res_query( const std::string& query, const bool mode_or );
 
         // number番のレスの文字列を返す
         // ref == true なら先頭に ">" を付ける
-        const std::string get_res_str( int number, bool ref = false );
+        std::string get_res_str( int number, bool ref = false );
 
         // number　番のレスの生文字列を返す
-        const std::string get_raw_res_str( int number );
+        std::string get_raw_res_str( int number );
 
         // 書き込み時の名前とメアド
         const std::string& get_write_name() const { return m_write_name; }
@@ -227,23 +228,23 @@ namespace DBTREE
         void set_write_fixmail( bool set ){ m_save_info = true; m_write_fixmail = set; }
 
         // 書き込みメッセージ作成
-        virtual const std::string create_write_message( const std::string& name, const std::string& mail, const std::string& msg )
-        { return std::string(); }
+        virtual std::string create_write_message( const std::string& name, const std::string& mail,
+                                                  const std::string& msg ) { return {}; }
 
         // bbscgi のURL
-        virtual const std::string url_bbscgi() { return std::string(); }
+        virtual std::string url_bbscgi() { return std::string(); }
 
         // subbbscgi のURL
-        virtual const std::string url_subbbscgi() { return std::string(); }
+        virtual std::string url_subbbscgi() { return std::string(); }
 
         // 最終アクセス時間
-        const std::string get_access_time_str();
-        const time_t& get_access_time() const { return m_access_time.tv_sec; } // 秒
+        std::string get_access_time_str();
+        time_t get_access_time() const { return m_access_time.tv_sec; } // 秒
         const std::string& get_access_date(); // string型
         void reset_access_date(){ m_access_date = std::string(); }
 
         // 最終書き込み時間
-        const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
+        time_t get_write_time() const { return m_write_time.tv_sec; } // 秒
         const std::string& get_write_date(); // string型
         void reset_write_date(){ m_write_time_date = std::string(); }
 
@@ -263,7 +264,7 @@ namespace DBTREE
         void clear_post_history();
 
         // スレ立て時刻
-        const time_t& get_since_time() const { return m_since_time; };
+        time_t get_since_time() const { return m_since_time; };
         const std::string& get_since_date();
         void reset_since_date(){ m_since_date = std::string(); }
 
@@ -317,7 +318,7 @@ namespace DBTREE
         const std::list< std::string >& get_abone_list_name(){ return m_list_abone_name; }
         const std::list< std::string >& get_abone_list_word(){ return m_list_abone_word; }
         const std::list< std::string >& get_abone_list_regex(){ return m_list_abone_regex; }
-        const std::vector< char >& get_abone_vec_res(){ return m_vec_abone_res; }
+        const std::unordered_set< int >& get_abone_reses() const noexcept { return m_abone_reses; }
 
         // 透明
         bool get_abone_transparent();
@@ -379,7 +380,7 @@ namespace DBTREE
         virtual void save_info( const bool force );
 
         bool is_loading() const; // ロード中か
-        bool is_checking_update();  // 更新チェック中か
+        bool is_checking_update() const;  // 更新チェック中か
 
         // スレッドのロード停止
         void stop_load();
@@ -395,7 +396,7 @@ namespace DBTREE
         // ロード終了時( slot_load_finished() )に次スレ移行チェックをする
         void set_url_pre_article( const std::string& url_pre_article );
 
-        // url_src で示されるスレの情報をコピー
+        // url_src で示されるスレの情報を引き継ぐ
         void copy_article_info( const std::string& url_src );
 
         // スレッド924か
