@@ -277,12 +277,7 @@ void Root::load_cache()
 {
     clear();
 
-    // ファイルが存在しなければ入力を旧ファイル名にする
     std::string file_in = CACHE::path_xml_listmain();
-    if( CACHE::file_exists( file_in ) != CACHE::EXIST_FILE )
-    {
-        file_in = CACHE::path_xml_listmain_old();
-    }
 
 #ifdef _DEBUG
     std::cout << "Root::load_cache xml  = " << file_in << std::endl;
@@ -559,7 +554,7 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     else if( is_JBBS( url ) ){
 
         if( regex.exec( "(https?://[^/]*)/(.*)/(index2?\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
-            root = "http://jbbs.shitaraba.net";
+            root = regex.str( 1 );
             path_board = "/" + regex.str( 2 );
 
             type = TYPE_BOARD_JBBS;
@@ -1315,7 +1310,7 @@ void Root::load_movetable()
 //
 // 移転した時は移転後のURLを返す
 //
-const std::string Root::is_board_moved( const std::string& url ) // 簡易版
+std::string Root::is_board_moved( const std::string& url ) // 簡易版
 {
     std::string old_root;
     std::string old_path_board;
@@ -1325,13 +1320,12 @@ const std::string Root::is_board_moved( const std::string& url ) // 簡易版
 }
 
 
-const std::string Root::is_board_moved( const std::string& url,
-                                        std::string& old_root,
-                                        std::string& old_path_board,
-                                        std::string& new_root,
-                                        std::string& new_path_board,
-                                        const int count
-    )
+std::string Root::is_board_moved( const std::string& url,
+                                  std::string& old_root,
+                                  std::string& old_path_board,
+                                  std::string& new_root,
+                                  std::string& new_path_board,
+                                  const int count )
 {
     const int max_count = 50;
 
@@ -1486,7 +1480,7 @@ void Root::save_articleinfo_all()
 
 // 全ログ検索
 void Root::search_cache( std::vector< ArticleBase* >& list_article,
-                         const std::string& query, const bool mode_or, const bool bm, const bool& stop )
+                         const std::string& query, const bool mode_or, const bool bm, const bool stop )
 {
     std::list< BoardBase* >::iterator it;
     for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
