@@ -27,6 +27,12 @@
 #include <windows.h>
 #endif
 
+#if defined(USE_GNUTLS)
+#  include <gnutls/gnutls.h>
+#elif defined(USE_OPENSSL)
+#  include <openssl/ssl.h>
+#endif
+
 std::string ENVIRONMENT::get_progname() { return "JDim"; }
 std::string ENVIRONMENT::get_jdcomments(){ return std::string( JDCOMMENT ); }
 std::string ENVIRONMENT::get_jdcopyright(){ return std::string( JDCOPYRIGHT ); }
@@ -37,7 +43,7 @@ std::string ENVIRONMENT::get_jdhelpcmd(){ return std::string( JDHELPCMD ); }
 std::string ENVIRONMENT::get_jdlicense(){ return std::string( JDLICENSE ); }
 
 
-int window_manager = ENVIRONMENT::WM_UNKNOWN;
+static ENVIRONMENT::DesktopType window_manager = ENVIRONMENT::DesktopType::unknown;
 
 
 //
@@ -509,33 +515,48 @@ std::string ENVIRONMENT::get_distname()
 }
 
 
+static constexpr const char* tbl_desktop[] = {
+    "GNOME", "XFCE", "KDE", "LXDE", "UNITY", "CINNAMON", "MATE",
+    "BUDGIE", "PANTHEON", "ENLIGHTENMENT", "LXQT", "(unknown)" };
+
 //
 // WM 判定
 // TODO: 環境変数で判定できない場合の判定方法を考える
 //
-int ENVIRONMENT::get_wm()
+ENVIRONMENT::DesktopType ENVIRONMENT::get_wm()
 {
-    if( window_manager != WM_UNKNOWN ) return window_manager;
+#ifndef _WIN32
+    if( window_manager != DesktopType::unknown ) return window_manager;
 
-    const std::string str_wm = MISC::getenv_limited( "DESKTOP_SESSION", 5 );
+    constexpr const char* envvar[] = { "DESKTOP_SESSION", "XDG_CURRENT_DESKTOP" };
 
-    if( str_wm.find( "xfce" ) != std::string::npos ) window_manager = WM_XFCE;
-    else if( str_wm.find( "gnome" ) != std::string::npos ) window_manager = WM_GNOME;
-    else if( str_wm.find( "kde" ) != std::string::npos ) window_manager = WM_KDE;
-    else if( str_wm.find( "LXDE" ) != std::string::npos ) window_manager = WM_LXDE;
+    for( const char* v : envvar ) {
 
-    if( window_manager == WM_UNKNOWN )
+        const std::string str_wm = MISC::toupper_str( MISC::getenv_limited( v, 20 ) );
+
+        if( !str_wm.empty() ){
+            constexpr auto table_size = static_cast< std::size_t >( DesktopType::unknown );
+            for( std::size_t i = 0; i < table_size; ++i ){
+                if( str_wm.find( tbl_desktop[ i ] ) != std::string::npos ){
+                    window_manager = static_cast< DesktopType >( i );
+                }
+            }
+        }
+    }
+
+    if( window_manager == DesktopType::unknown )
     {
         if( ! MISC::getenv_limited( "GNOME_DESKTOP_SESSION_ID" ).empty() )
         {
-            window_manager = WM_GNOME;
+            window_manager = DesktopType::gnome;
         }
         else
         {
             const std::string str_wm = MISC::getenv_limited( "KDE_FULL_SESSION", 4 );
-            if( str_wm == "true" ) window_manager = WM_KDE;
+            if( str_wm == "true" ) window_manager = DesktopType::kde;
         }
     }
+#endif
 
     return window_manager;
 }
@@ -550,18 +571,12 @@ std::string ENVIRONMENT::get_wm_str()
 
 #ifdef _WIN32
 #ifdef __MINGW32__
-    return std::string( "build by mingw32" );
+    desktop = "build by mingw32";
 #else
-    return std::string( "build with _WIN32" );
+    desktop = "build with _WIN32";
 #endif
 #else
-    switch( get_wm() )
-    {
-        case WM_GNOME : desktop = "GNOME"; break;
-        case WM_XFCE  : desktop = "XFCE";  break;
-        case WM_KDE   : desktop = "KDE";   break;
-        case WM_LXDE  : desktop = "LXDE";  break;
-    }
+    desktop = tbl_desktop[ static_cast< int >( get_wm() ) ];
 #endif
 
     return desktop;
@@ -596,6 +611,25 @@ std::string ENVIRONMENT::get_glibmm_version()
 }
 
 
+//
+// TLSライブラリのバージョンを取得
+//
+std::string ENVIRONMENT::get_tlslib_version()
+{
+    std::string version;
+
+#if defined(USE_GNUTLS)
+    version = "GnuTLS ";
+    version += gnutls_check_version(nullptr);
+#elif defined(USE_OPENSSL)
+    version = SSLeay_version(SSLEAY_VERSION);
+#endif
+
+    return version;
+}
+
+
+
 //
 // 動作環境を取得
 //
@@ -631,7 +665,8 @@ std::string ENVIRONMENT::get_jdinfo()
     "[パッケージ] " << "バイナリ/ソース( <配布元> )" << "\n" <<
     "[ DE／WM ] " << desktop << "\n" <<
     "[　gtkmm 　] " << get_gtkmm_version() << "\n" <<
-    "[　glibmm 　] " << get_glibmm_version()<< "\n" <<
+    "[　glibmm 　] " << get_glibmm_version() << "\n" <<
+    "[　TLS lib　] " << get_tlslib_version() << "\n" <<
 #ifdef CONFIGURE_ARGS
     "[オプション ] " << get_configure_args( CONFIGURE_OMITTED_MULTILINE ) << "\n" <<
 #endif
