@@ -48,7 +48,13 @@ ImageAdmin::ImageAdmin( const std::string& url )
     , m_scroll( SCROLL_NO )
 {
     m_scrwin.add( m_iconbox );
+#if GTKMM_CHECK_VERSION(3,16,0)
+    // Gtk::POLICY_NEVERだとスクロール機能自体がなくなり
+    // コンテンツに合わせてGtk::ScrolledWindowのサイズが拡大してしまう
+    m_scrwin.set_policy( Gtk::POLICY_EXTERNAL, Gtk::POLICY_NEVER );
+#else
     m_scrwin.set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_NEVER );
+#endif
     m_scrwin.set_size_request( ICON_SIZE ,  ICON_SIZE + 4);
 
     m_left.set_label( "<" );
@@ -175,7 +181,7 @@ int ImageAdmin::get_tab_nums()
 //
 // 含まれているページのURLのリスト取得
 //
-const std::list< std::string > ImageAdmin::get_URLs()
+std::list< std::string > ImageAdmin::get_URLs()
 {
     std::list< std::string > urls;
     m_iconbox.foreach( [&urls]( Gtk::Widget& w ) {
