@@ -1105,7 +1105,7 @@ struct addrinfo* Loader::get_addrinfo( const std::string& hostname, const int po
 //
 // 送信メッセージ作成
 //
-const std::string Loader::create_msg_send()
+std::string Loader::create_msg_send()
 {
     bool post_msg = ( !m_data.str_post.empty() && !m_data.head );
     bool use_proxy = ( ! m_data.host_proxy.empty() );
@@ -1513,8 +1513,8 @@ bool Loader::init_unzip()
 
     assert( m_buf_zlib_in == NULL );
     assert( m_buf_zlib_out == NULL );
-    m_buf_zlib_in = ( Bytef* )malloc( m_lng_buf_zlib_in + 64 );
-    m_buf_zlib_out = ( Bytef* )malloc( m_lng_buf_zlib_out + 64 );
+    m_buf_zlib_in = ( Bytef* )malloc( sizeof( Bytef ) * m_lng_buf_zlib_in + 64 );
+    m_buf_zlib_out = ( Bytef* )malloc( sizeof( Bytef ) * m_lng_buf_zlib_out + 64 );
 
     return true;
 }
