@@ -21,7 +21,7 @@
 //
 // str を "\n" ごとに区切ってlistにして出力
 //
-const std::list< std::string > MISC::get_lines( const std::string& str ){
+std::list< std::string > MISC::get_lines( const std::string& str ){
         
     std::list< std::string > lines;
     size_t i = 0, i2 = 0, r = 0;
@@ -44,7 +44,7 @@ const std::list< std::string > MISC::get_lines( const std::string& str ){
 //
 // emacs lisp のリスト型を要素ごとにlistにして出力
 //
-const std::list< std::string > MISC::get_elisp_lists( const std::string& str )
+std::list< std::string > MISC::get_elisp_lists( const std::string& str )
 {
 #ifdef _DEBUG
     std::cout << "MISC::get_elisp_lists\n";
@@ -109,10 +109,10 @@ const std::list< std::string > MISC::get_elisp_lists( const std::string& str )
 //
 // strを空白または "" 単位で区切って list で出力
 //
-const std::list< std::string > MISC::split_line( const std::string& str )
+std::list< std::string > MISC::split_line( const std::string& str )
 {
-    std::string str_space = "　";
-    size_t lng_space = str_space.length();
+    constexpr const char* str_space = u8"\u3000"; // "\xE3\x80\x80" 全角スペース
+    constexpr size_t lng_space = 3;
     bool dquote;
 
     std::list< std::string > list_str;
@@ -129,7 +129,7 @@ const std::list< std::string > MISC::split_line( const std::string& str )
             // 全角
             else if( str[ i ] == str_space[ 0 ] &&
                      str[ i +1 ] == str_space[ 1 ] &&
-                     ( lng_space == 2 || str[ i +2 ] == str_space[ 2 ] ) ) i += lng_space;
+                     str[ i +2 ] == str_space[ 2 ] ) i += lng_space;
 
             else break;
         }
@@ -157,7 +157,7 @@ const std::list< std::string > MISC::split_line( const std::string& str )
                 // 全角
                 else if( str[ i2 ] == str_space[ 0 ] &&
                          str[ i2 +1 ] == str_space[ 1 ] &&
-                         ( lng_space == 2 || str[ i2 +2 ] == str_space[ 2 ] ) ){
+                         str[ i2 +2 ] == str_space[ 2 ] ){
                     lng_tmp = lng_space;
                     break;
                 }
@@ -176,7 +176,7 @@ const std::list< std::string > MISC::split_line( const std::string& str )
 
 
 // strを delimで区切って list で出力
-const std::list< std::string > MISC::StringTokenizer( const std::string& str, const char delim )
+std::list< std::string > MISC::StringTokenizer( const std::string& str, const char delim )
 {
     std::list< std::string > list_str;
 
@@ -198,7 +198,7 @@ const std::list< std::string > MISC::StringTokenizer( const std::string& str, co
 //
 // list_inから空白行を除いてリストを返す
 //
-const std::list< std::string > MISC::remove_nullline_from_list( const std::list< std::string >& list_in )
+std::list< std::string > MISC::remove_nullline_from_list( const std::list< std::string >& list_in )
 {
     std::list< std::string > list_ret;
     std::list< std::string >::const_iterator it;    
@@ -214,7 +214,7 @@ const std::list< std::string > MISC::remove_nullline_from_list( const std::list<
 //
 // list_inの各行から前後の空白を除いてリストを返す
 //
-const std::list< std::string > MISC::remove_space_from_list( const std::list< std::string >& list_in )
+std::list< std::string > MISC::remove_space_from_list( const std::list< std::string >& list_in )
 {
     std::list< std::string > list_ret;
     std::list< std::string >::const_iterator it;    
@@ -230,7 +230,7 @@ const std::list< std::string > MISC::remove_space_from_list( const std::list< st
 //
 // list_inからコメント行(#)を除いてリストを返す
 //
-const std::list< std::string > MISC::remove_commentline_from_list( const std::list< std::string >& list_in )
+std::list< std::string > MISC::remove_commentline_from_list( const std::list< std::string >& list_in )
 {
     const char commentchr = '#';
 
@@ -253,7 +253,7 @@ const std::list< std::string > MISC::remove_commentline_from_list( const std::li
 //
 // (例)  "aaa" "bbb" "\"ccc\""  → aaa と bbb と "ccc"
 //
-const std::list< std::string > MISC::strtolist( const std::string& str_in )
+std::list< std::string > MISC::strtolist( const std::string& str_in )
 {
     std::list< std::string > list_tmp;
     std::list< std::string > list_ret;
@@ -276,7 +276,7 @@ const std::list< std::string > MISC::strtolist( const std::string& str_in )
 //
 // (例)  "aaa" "bbb" "\"ccc\""
 //
-const std::string MISC::listtostr( const std::list< std::string >& list_in )
+std::string MISC::listtostr( const std::list< std::string >& list_in )
 {
     std::string str_out;
     std::list< std::string >::const_iterator it = list_in.begin();
@@ -292,15 +292,15 @@ const std::string MISC::listtostr( const std::list< std::string >& list_in )
 //
 // strの前後の空白削除
 //
-const std::string MISC::remove_space( const std::string& str )
+std::string MISC::remove_space( const std::string& str )
 {
-    std::string str_space = "　";
-    size_t lng_space = str_space.length();
+    constexpr const char* str_space = u8"\u3000"; // "\xE3\x80\x80" 全角スペース
+    constexpr size_t lng_space = 3;
 
     size_t lng = str.length();
     
     if( lng == 0 ) return str;
-    if( str.find( " " ) == std::string::npos ) return str;
+    if( str.find( ' ' ) == std::string::npos ) return str;
 
     // 前
     size_t i = 0;
@@ -312,7 +312,7 @@ const std::string MISC::remove_space( const std::string& str )
         // 全角
         else if( str[ i ] == str_space[ 0 ] &&
                  str[ i +1 ] == str_space[ 1 ] &&
-                 ( lng_space == 2 || str[ i +2 ] == str_space[ 2 ] ) ) i += lng_space;
+                 str[ i +2 ] == str_space[ 2 ] ) i += lng_space;
         else break;
     }
 
@@ -327,7 +327,7 @@ const std::string MISC::remove_space( const std::string& str )
         else if( i2 +1 >= lng_space &&
                  str[ i2 - lng_space +1 ] == str_space[ 0 ] &&
                  str[ i2 - lng_space +2 ] == str_space[ 1 ] &&
-                 ( lng_space == 2 || str[ i2 - lng_space +3 ] == str_space[ 2 ] ) ) i2 -= lng_space;
+                 str[ i2 - lng_space +3 ] == str_space[ 2 ] ) i2 -= lng_space;
         else break;
     }
 
@@ -338,7 +338,7 @@ const std::string MISC::remove_space( const std::string& str )
 //
 // str前後の改行、タブ、スペースを削除
 //
-const std::string MISC::remove_spaces( const std::string& str )
+std::string MISC::remove_spaces( const std::string& str )
 {
     if( str.empty() ) return std::string();
 
@@ -366,7 +366,7 @@ const std::string MISC::remove_spaces( const std::string& str )
 //
 // str1からstr2で示された文字列を除く
 //
-const std::string MISC::remove_str( const std::string& str1, const std::string& str2 )
+std::string MISC::remove_str( const std::string& str1, const std::string& str2 )
 {
     return MISC::replace_str( str1, str2, "" );
 }
@@ -375,7 +375,7 @@ const std::string MISC::remove_str( const std::string& str1, const std::string&
 //
 // start 〜 end の範囲をstrから取り除く ( /* コメント */ など )
 //
-const std::string MISC::remove_str( const std::string& str, const std::string& start, const std::string& end )
+std::string MISC::remove_str( const std::string& str, const std::string& start, const std::string& end )
 {
     std::string str_out = str;
 
@@ -397,7 +397,7 @@ const std::string MISC::remove_str( const std::string& str, const std::string& s
 //
 // 正規表現を使ってstr1からqueryで示された文字列を除く
 //
-const std::string MISC::remove_str_regex( const std::string& str1, const std::string& query )
+std::string MISC::remove_str_regex( const std::string& str1, const std::string& query )
 {
     JDLIB::Regex regex;
     const size_t offset = 0;
@@ -413,7 +413,7 @@ const std::string MISC::remove_str_regex( const std::string& str1, const std::st
 //
 // str1, str2 に囲まれた文字列を切り出す
 //
-const std::string MISC::cut_str( const std::string& str, const std::string& str1, const std::string& str2 )
+std::string MISC::cut_str( const std::string& str, const std::string& str1, const std::string& str2 )
 {
     size_t i = str.find( str1 );
     if( i == std::string::npos ) return std::string();
@@ -428,7 +428,7 @@ const std::string MISC::cut_str( const std::string& str, const std::string& str1
 //
 // str1 を str2 に置き換え
 //
-const std::string MISC::replace_str( const std::string& str, const std::string& str1, const std::string& str2 )
+std::string MISC::replace_str( const std::string& str, const std::string& str1, const std::string& str2 )
 {
     size_t i, pos = 0;
     if( ( i = str.find( str1 , pos ) ) == std::string::npos ) return str;
@@ -451,7 +451,7 @@ const std::string MISC::replace_str( const std::string& str, const std::string&
 //
 // list_inから str1 を str2 に置き換えてリストを返す
 //
-const std::list< std::string > MISC::replace_str_list( const std::list< std::string >& list_in,
+std::list< std::string > MISC::replace_str_list( const std::list< std::string >& list_in,
                                                  const std::string& str1, const std::string& str2 )
 {
     std::list< std::string > list_out;
@@ -464,7 +464,7 @@ const std::list< std::string > MISC::replace_str_list( const std::list< std::str
 //
 // str_in に含まれる改行文字を replace に置き換え
 //
-const std::string MISC::replace_newlines_to_str( const std::string& str_in, const std::string& replace )
+std::string MISC::replace_newlines_to_str( const std::string& str_in, const std::string& replace )
 {
     if( str_in.empty() || replace.empty() ) return str_in;
 
@@ -491,7 +491,7 @@ const std::string MISC::replace_newlines_to_str( const std::string& str_in, cons
 //
 // " を \" に置き換え
 //
-const std::string MISC::replace_quot( const std::string& str )
+std::string MISC::replace_quot( const std::string& str )
 {
     return MISC::replace_str( str, "\"", "\\\"" );
 }
@@ -500,7 +500,7 @@ const std::string MISC::replace_quot( const std::string& str )
 //
 // \" を " に置き換え
 //
-const std::string MISC::recover_quot( const std::string& str )
+std::string MISC::recover_quot( const std::string& str )
 {
     return MISC::replace_str( str, "\\\"", "\"" );
 }
@@ -524,18 +524,6 @@ int MISC::count_str( const std::string& str, const std::string& str2  )
 }
 
 
-//
-// str 中に含まれている chr の 数を返す
-//
-int MISC::count_chr( const std::string& str, const char chr )
-{
-    int count = 0;
-    const int size = str.size();
-    for( int i = 0; i < size; ++i ) if( str.c_str()[i] == chr ) ++count;
-    return count;
-}
-
-
 //
 // 文字列(utf-8も) -> 整数変換
 //
@@ -591,7 +579,7 @@ int MISC::str_to_uint( const char* str, size_t& dig, size_t& n )
 //
 // 数字　-> 文字変換
 //
-const std::string MISC::itostr( const int n )
+std::string MISC::itostr( const int n )
 {
     std::ostringstream ss;
     ss << n;
@@ -603,7 +591,7 @@ const std::string MISC::itostr( const int n )
 //
 // listで指定した数字を文字に変換
 //
-const std::string MISC::intlisttostr( const std::list< int >& list_num )
+std::string MISC::intlisttostr( const std::list< int >& list_num )
 {
     std::ostringstream comment;
 
@@ -676,7 +664,7 @@ size_t MISC::chrtobin( const char* chr_in, char* chr_out )
 //
 // strが半角でmaxsize文字を超えたらカットして後ろに...を付ける
 //
-const std::string MISC::cut_str( const std::string& str, const unsigned int maxsize )
+std::string MISC::cut_str( const std::string& str, const unsigned int maxsize )
 {
     std::string outstr = str;
     unsigned int pos, lng_str;
@@ -745,7 +733,7 @@ bool MISC::has_regex_metachar( const std::string& str, const bool escape )
 //
 // escape == true ならエスケープを考慮 (例)  escape == true なら \+ → \+ のまま、falseなら \+ → \\\+
 //
-const std::string MISC::regex_escape( const std::string& str, const bool escape )
+std::string MISC::regex_escape( const std::string& str, const bool escape )
 {
     if( ! has_regex_metachar( str, escape ) ) return str;
 
@@ -802,7 +790,7 @@ const std::string MISC::regex_escape( const std::string& str, const bool escape
 //
 // 正規表現のメタ文字をアンエスケープ
 //
-const std::string MISC::regex_unescape( const std::string& str )
+std::string MISC::regex_unescape( const std::string& str )
 {
 #ifdef _DEBUG
     std::cout << "MISC::regex_unescape" << std::endl;
@@ -844,7 +832,7 @@ const std::string MISC::regex_unescape( const std::string& str )
 //
 // include_url : URL中でもエスケープする( デフォルト = true )
 //
-const std::string MISC::html_escape( const std::string& str, const bool include_url )
+std::string MISC::html_escape( const std::string& str, const bool include_url )
 {
     if( str.empty() ) return str;
 
@@ -908,7 +896,7 @@ const std::string MISC::html_escape( const std::string& str, const bool include_
 //
 // HTMLアンエスケープ
 //
-const std::string MISC::html_unescape( const std::string& str )
+std::string MISC::html_unescape( const std::string& str )
 {
     if( str.empty() ) return str;
     if( str.find( "&" ) == std::string::npos ) return str;
@@ -982,13 +970,15 @@ int MISC::is_url_scheme_impl( const char* str_in, int* length )
         if( *( str_in + len ) == 's' ) ++len;
     }
     // sssp
-    // デフォルトでモザイクを解除するのでimg.2ch以外のアドレスにはリンクを張らない
-    else if( *str_in == 's' && *( str_in + 1 ) == 's' && *( str_in + 2 ) == 's' && *( str_in + 3 ) == 'p'
-             && *( str_in + 7 ) == 'i' && *( str_in + 8 ) == 'm' && *( str_in + 9 ) == 'g' && *( str_in + 10 ) == '.'
-             && *( str_in + 11 ) == '2' && *( str_in + 12 ) == 'c' && *( str_in + 13 ) == 'h'
-        )
-    {
-        scheme = SCHEME_SSSP;
+    else if( *str_in == 's' && *( str_in + 1 ) == 's' && *( str_in + 2 ) == 's' && *( str_in + 3 ) == 'p' ){
+        if( *( str_in + 7 ) == 'i' && *( str_in + 8 ) == 'm' && *( str_in + 9 ) == 'g' && *( str_in + 10 ) == '.'
+             && *( str_in + 11 ) == '2' && *( str_in + 12 ) == 'c' && *( str_in + 13 ) == 'h'){
+            scheme = SCHEME_SSSP;
+        }
+        else{
+            // XXX img.2ch以外のアドレスはHTTPスキームにする
+            scheme = SCHEME_HTTP;
+        }
         len = 4;
     }
 
@@ -1054,7 +1044,7 @@ bool MISC::is_url_char( const char* str_in, const bool loose_url )
 //
 // URLデコード
 //
-const std::string MISC::url_decode( const std::string& url )
+std::string MISC::url_decode( const std::string& url )
 {
     if( url.empty() ) return std::string();
 
@@ -1099,7 +1089,7 @@ const std::string MISC::url_decode( const std::string& url )
 //
 // url エンコード
 //
-const std::string MISC::url_encode( const char* str, const size_t n )
+std::string MISC::url_encode( const char* str, const size_t n )
 {
     if( str[ n ] != '\0' ){
         ERRMSG( "url_encode : invalid input." );
@@ -1137,7 +1127,7 @@ const std::string MISC::url_encode( const char* str, const size_t n )
 }
 
 
-const std::string MISC::url_encode( const std::string& str )
+std::string MISC::url_encode( const std::string& str )
 {
     return url_encode( str.c_str(), str.length() );
 }
@@ -1148,7 +1138,7 @@ const std::string MISC::url_encode( const std::string& str )
 //
 // str は UTF-8 であること
 //
-const std::string MISC::charset_url_encode( const std::string& str, const std::string& charset )
+std::string MISC::charset_url_encode( const std::string& str, const std::string& charset )
 {
     if( charset.empty() || charset == "UTF-8" ) return MISC::url_encode( str.c_str(), str.length() );
 
@@ -1162,7 +1152,7 @@ const std::string MISC::charset_url_encode( const std::string& str, const std::s
 //
 // ただし半角スペースのところを+に置き換えて区切る
 //
-const std::string MISC::charset_url_encode_split( const std::string& str, const std::string& charset )
+std::string MISC::charset_url_encode_split( const std::string& str, const std::string& charset )
 {
     std::list< std::string > list_str = MISC::split_line( str );
     std::list< std::string >::iterator it = list_str.begin();
@@ -1180,7 +1170,7 @@ const std::string MISC::charset_url_encode_split( const std::string& str, const
 //
 // BASE64
 //
-const std::string MISC::base64( const std::string& str )
+std::string MISC::base64( const std::string& str )
 {
     char table[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
@@ -1230,7 +1220,7 @@ const std::string MISC::base64( const std::string& str )
 //
 // 遅いので連続的な処理が必要な時は使わないこと
 //
-const std::string MISC::Iconv( const std::string& str, const std::string& coding_from, const std::string& coding_to )
+std::string MISC::Iconv( const std::string& str, const std::string& coding_from, const std::string& coding_to )
 {
     if( coding_from == coding_to ) return str;
 
@@ -1305,6 +1295,87 @@ int MISC::spchar_number_ln( const char* in_char, int& offset )
 }
 
 
+// 特定の変換が必要なコードポイントをチェックする
+static int transform_7f_9f( int raw_point )
+{
+    switch( raw_point ) {
+        case 0x80: return 0x20AC; // EURO SIGN (€)
+        case 0x82: return 0x201A; // SINGLE LOW-9 QUOTATION MARK (‚)
+        case 0x83: return 0x0192; // LATIN SMALL LETTER F WITH HOOK (ƒ)
+        case 0x84: return 0x201E; // DOUBLE LOW-9 QUOTATION MARK („)
+        case 0x85: return 0x2026; // HORIZONTAL ELLIPSIS (…)
+        case 0x86: return 0x2020; // DAGGER (†)
+        case 0x87: return 0x2021; // DOUBLE DAGGER (‡)
+        case 0x88: return 0x02C6; // MODIFIER LETTER CIRCUMFLEX ACCENT (ˆ)
+        case 0x89: return 0x2030; // PER MILLE SIGN (‰)
+        case 0x8A: return 0x0160; // LATIN CAPITAL LETTER S WITH CARON (Š)
+        case 0x8B: return 0x2039; // SINGLE LEFT-POINTING ANGLE QUOTATION MARK (‹)
+        case 0x8C: return 0x0152; // LATIN CAPITAL LIGATURE OE (Œ)
+        case 0x8E: return 0x017D; // LATIN CAPITAL LETTER Z WITH CARON (Ž)
+        case 0x91: return 0x2018; // LEFT SINGLE QUOTATION MARK (‘)
+        case 0x92: return 0x2019; // RIGHT SINGLE QUOTATION MARK (’)
+        case 0x93: return 0x201C; // LEFT DOUBLE QUOTATION MARK (“)
+        case 0x94: return 0x201D; // RIGHT DOUBLE QUOTATION MARK (”)
+        case 0x95: return 0x2022; // BULLET (•)
+        case 0x96: return 0x2013; // EN DASH (–)
+        case 0x97: return 0x2014; // EM DASH (—)
+        case 0x98: return 0x02DC; // SMALL TILDE (˜)
+        case 0x99: return 0x2122; // TRADE MARK SIGN (™)
+        case 0x9A: return 0x0161; // LATIN SMALL LETTER S WITH CARON (š)
+        case 0x9B: return 0x203A; // SINGLE RIGHT-POINTING ANGLE QUOTATION MARK (›)
+        case 0x9C: return 0x0153; // LATIN SMALL LIGATURE OE (œ)
+        case 0x9E: return 0x017E; // LATIN SMALL LETTER Z WITH CARON (ž)
+        case 0x9F: return 0x0178; // LATIN CAPITAL LETTER Y WITH DIAERESIS (Ÿ)
+        default:
+            return 0xFFFD; // REPLACEMENT CHARACTER
+    }
+}
+
+//
+// コードポイントが数値文字参照としてはエラーなら規定の値へ変換する
+// 例えばサロゲートペアは'REPLACEMENT CHARACTER' (U+FFFD)を返す
+//
+// 参考文献 : Numeric character reference end state (HTML 5.3)
+//            https://www.w3.org/TR/html53/syntax.html#numeric-character-reference-end-state
+//
+static int sanitize_numeric_character_reference( int raw_point )
+{
+    // NOTE: 記号や絵文字を速やかに処理できるよう順番が組まれている
+
+    bool parse_error = false;
+
+    // 基本多言語面(BMP)をおおまかにチェック
+    if( 0x009F < raw_point && raw_point < 0xD800 ) return raw_point;
+    // 特定のbitパターンの非文字と符号空間の範囲をチェック
+    else if( ( raw_point & 0xFFFE ) == 0xFFFE || raw_point > 0x10FFFF ) parse_error = true;
+    // bitパターンを除いたらBMPの一部と追加多言語面(SMP)以降をチェック
+    else if( 0xFDEF < raw_point ) return raw_point;
+    // サロゲートペアはエラー
+    else if( 0xD800 <= raw_point && raw_point <= 0xDFFF ) parse_error = true;
+
+    // 基本ラテン文字をチェック
+    else if( 0x001F < raw_point && raw_point < 0x007F ) return raw_point;
+    // 特定の変換が必要なコードポイントをチェック
+    else if( 0x007F <= raw_point && raw_point <= 0x009F ) return transform_7f_9f( raw_point );
+    // 最後に制御文字と非文字をチェック
+    // サロゲートペアは他の値より入力される可能性が高いので処理を優先している
+    else if( raw_point <= 0x0008 // Control character
+            || raw_point == 0x000B // Control character (Vertical tab)
+            || ( 0x000D <= raw_point && raw_point <= 0x001F ) // Control character
+            || ( 0xFDD0 <= raw_point && raw_point <= 0xFDEF ) // Noncharacters
+            ) {
+        parse_error = true;
+    }
+
+    if( parse_error ) {
+#ifdef _DEBUG
+        std::cout << "Parse error for numeric character reference... " << raw_point << std::endl;
+#endif
+        return 0xFFFD; // REPLACEMENT CHARACTER
+    }
+    return raw_point;
+}
+
 //
 // 「&#数字;」形式の数字参照文字列を数字(int)に変換する
 //
@@ -1331,14 +1402,14 @@ int MISC::decode_spchar_number( const char* in_char, const int offset, const int
     if( offset == 2 ) num = atoi( str_num );
     else num = strtol( str_num, NULL, 16 );
 
-    return num;
+    return sanitize_numeric_character_reference( num );
 }
 
 
 //
 // str に含まれる「&#数字;」形式の数字参照文字列を全てユニーコード文字に変換する
 //
-const std::string MISC::decode_spchar_number( const std::string& str )
+std::string MISC::decode_spchar_number( const std::string& str )
 {
     std::string str_out;
     const size_t str_length = str.length();
@@ -1485,7 +1556,7 @@ int MISC::get_ucs2mode( const int ucs2 )
 //
 // WAVEDASHなどのWindows系UTF-8文字をUnix系文字と相互変換
 //
-const std::string MISC::utf8_fix_wavedash( const std::string& str, const int mode )
+std::string MISC::utf8_fix_wavedash( const std::string& str, const int mode )
 {
     // WAVE DASH 問題
     const size_t size = 4;
@@ -1538,7 +1609,7 @@ const std::string MISC::utf8_fix_wavedash( const std::string& str, const int mod
 //
 // str を大文字化
 //
-const std::string MISC::toupper_str( const std::string& str )
+std::string MISC::toupper_str( const std::string& str )
 {
     std::string str_out;
     const size_t str_length = str.length();
@@ -1552,7 +1623,7 @@ const std::string MISC::toupper_str( const std::string& str )
 //
 // list 内のアイテムを全部大文字化
 //
-const std::list< std::string > MISC::toupper_list( const std::list< std::string >& list_str )
+std::list< std::string > MISC::toupper_list( const std::list< std::string >& list_str )
 {
     std::list< std::string > list_out;
     std::list< std::string >::const_iterator it = list_str.begin();
@@ -1566,7 +1637,7 @@ const std::list< std::string > MISC::toupper_list( const std::list< std::string
 //
 // str を小文字化
 //
-const std::string MISC::tolower_str( const std::string& str )
+std::string MISC::tolower_str( const std::string& str )
 {
     std::string str_out;
     const size_t str_length = str.length();
@@ -1583,7 +1654,7 @@ const std::string MISC::tolower_str( const std::string& str )
 //
 // protocol = false のときはプロトコルを除く
 //
-const std::string MISC::get_hostname( const std::string& path, bool protocol )
+std::string MISC::get_hostname( const std::string& path, bool protocol )
 {
     int lng = 0;
     if( path.find( "http://" ) == 0 ) lng = strlen( "http://" );
@@ -1606,7 +1677,7 @@ const std::string MISC::get_hostname( const std::string& path, bool protocol )
 //
 // path からファイル名だけ取り出す
 //
-const std::string MISC::get_filename( const std::string& path )
+std::string MISC::get_filename( const std::string& path )
 {
     if( path.empty() ) return std::string();
 
@@ -1621,7 +1692,7 @@ const std::string MISC::get_filename( const std::string& path )
 //
 // path からファイル名を除いてディレクトリだけ取り出す
 //
-const std::string MISC::get_dir( const std::string& path )
+std::string MISC::get_dir( const std::string& path )
 {
     if( path.empty() ) return std::string();
 
@@ -1636,7 +1707,7 @@ const std::string MISC::get_dir( const std::string& path )
 //
 // 文字数を限定して環境変数の値を返す
 //
-const std::string MISC::getenv_limited( const char *name, const size_t size )
+std::string MISC::getenv_limited( const char *name, const size_t size )
 {
     if( ! name || ! getenv( name ) ) return std::string();
 
@@ -1654,7 +1725,7 @@ const std::string MISC::getenv_limited( const char *name, const size_t size )
 //
 // pathセパレータを / に置き換える
 //
-const std::string MISC::recover_path( const std::string& str )
+std::string MISC::recover_path( const std::string& str )
 {
 #ifdef _WIN32
     // Windowsのpathセパレータ \ を、jdの / に置き換える
@@ -1734,59 +1805,44 @@ bool MISC::has_widechar( const char* str )
 // 全角英数字(str1) -> 半角英数字(str2)
 //
 // table_pos : 置き換えた文字列の位置
-// n : str2 と table_pos のバッファサイズ
 //
-void MISC::asc( const char* str1, char* str2, int* table_pos, const size_t n )
+void MISC::asc( const char* str1, std::string& str2, std::vector< int >& table_pos )
 {
-    const size_t mrg = 18;
-    size_t pos = 0;
-    size_t pos2 = 0;
+    for( int pos = 0; str1[ pos ] != '\0'; ) {
+        assert( pos >= 0 );
+        assert( table_pos.max_size() > table_pos.size() );
+        const auto in1 = static_cast< unsigned char >( str1[ pos ] );
 
-    while( pos2 < ( n - mrg ) && *( str1 + pos ) != '\0' ){
-
-        const unsigned char in = *( str1 + pos );
-
-        if( in == 0xef ){
-
-            const unsigned char in2 = * ( str1 + pos + 1 );
-            const unsigned char in3 = * ( str1 + pos + 2 );
+        if( in1 == 0xef ) {
+            const auto in2 = static_cast< unsigned char >( str1[ pos + 1 ] );
+            const auto in3 = static_cast< unsigned char >( str1[ pos + 2 ] );
 
             if( in2 == 0xbc ){
-
-                //  全角数字
+                //  全角数字 (U+FF10 - U+FF19)
                 if( 0x90 <= in3 && in3 <= 0x99 ){
-
-                    str2[ pos2 ] = '0' + in3 - 0x90;;
-                    table_pos[ pos2 ] = pos;
+                    str2.push_back( '0' + in3 - 0x90 );
+                    table_pos.push_back( pos );
                     pos += 3;
-                    ++pos2;
                     continue;
                 }
-
-                //  全角大文字
+                //  全角大文字 (U+FF21 - U+FF3A)
                 else if( 0xa1 <= in3 && in3 <= 0xba ){
-
-                    str2[ pos2 ] = 'A' + in3 - 0xa1;
-                    table_pos[ pos2 ] = pos;
-
+                    str2.push_back( 'A' + in3 - 0xa1 );
+                    table_pos.push_back( pos );
                     pos += 3;
-                    ++pos2;
                     continue;
                 }
             }
 
-            //  全角小文字
+            //  全角小文字 (U+FF41 - U+FF5A)
             else if( in2 == 0xbd && ( 0x81 <= in3 && in3 <= 0x9a ) ){
-
-                str2[ pos2 ] = 'a' + in3 - 0x81;
-                table_pos[ pos2 ] = pos;
-
+                str2.push_back( 'a' + in3 - 0x81 );
+                table_pos.push_back( pos );
                 pos += 3;
-                ++pos2;
                 continue;
             }
 
-            // 半角かな
+            // 半角かな (U+FF61 - U+FF9F)
             else if( ( in2 == 0xbd && ( 0xa1 <= in3 && in3 <= 0xbf ) )
                      || ( in2 == 0xbe && ( 0x80 <= in3 && in3 <= 0x9f ) ) ){
 
@@ -1795,18 +1851,16 @@ void MISC::asc( const char* str1, char* str2, int* table_pos, const size_t n )
                 size_t i = 0;
 
                 // 濁点、半濁点
-                const unsigned char in4 = * ( str1 + pos + 3 );
-                const unsigned char in5 = * ( str1 + pos + 4 );
+                const auto in4 = static_cast< unsigned char >( str1[ pos + 3 ] );
+                const auto in5 = static_cast< unsigned char >( str1[ pos + 4 ] );
                 if( in4 == 0xef && in5 == 0xbe ){
-
-                    const unsigned char in6 = * ( str1 + pos + 5 );
+                    const auto in6 = static_cast< unsigned char >( str1[ pos + 5 ] );
 
                     // 濁点
                     if( in6 == 0x9e ){
                         dakuten = true;
                         i = 61;
                     }
-
                     // 半濁点
                     else if( in6 == 0x9f ){
                         dakuten = true;
@@ -1816,16 +1870,14 @@ void MISC::asc( const char* str1, char* str2, int* table_pos, const size_t n )
 
                 while( !flag_hkana && hkana_table1[ i ][ 0 ][ 0 ] != '\0' ){
 
-                    if( in == hkana_table1[ i ][ 0 ][ 0 ] && in2 == hkana_table1[ i ][ 0 ][ 1 ] && in3 == hkana_table1[ i ][ 0 ][ 2 ] ){
+                    if( in1 == hkana_table1[ i ][ 0 ][ 0 ]
+                            && in2 == hkana_table1[ i ][ 0 ][ 1 ]
+                            && in3 == hkana_table1[ i ][ 0 ][ 2 ] ) {
 
-                        str2[ pos2 ] = hkana_table1[ i ][ 1 ][ 0 ];
-                        str2[ pos2 +1 ] = hkana_table1[ i ][ 1 ][ 1 ];
-                        str2[ pos2 +2 ] = hkana_table1[ i ][ 1 ][ 2 ];
-                        table_pos[ pos2 ] = pos;
+                        std::copy_n( hkana_table1[ i ][ 1 ], 3, std::back_inserter( str2 ) );
+                        std::generate_n( std::back_inserter( table_pos ), 3, [&pos]{ return pos++; } );
 
-                        pos += 3;
                         if( dakuten ) pos += 3;
-                        pos2 += 3;
                         flag_hkana = true;
                     }
                     ++i;
@@ -1834,18 +1886,8 @@ void MISC::asc( const char* str1, char* str2, int* table_pos, const size_t n )
             }
         }
 
-        str2[ pos2 ] = str1[ pos ];
-        table_pos[ pos2 ] = pos;
-
+        str2.push_back( str1[ pos ] );
+        table_pos.push_back( pos );
         ++pos;
-        ++pos2;
     }
-
-    if( pos2 >= ( n - mrg ) ){
-        ERRMSG( "MISC::asc : buffer overflow." );
-        pos2 = ( n - mrg ) - 1;
-    }
-
-    table_pos[ pos2 ] = pos;
-    str2[ pos2 ] = '\0';
 }
