@@ -145,7 +145,7 @@ Gtk::Window* MessageViewBase::get_parent_win()
 //
 // メインウィンドウのURLバーなどに表示する)
 //
-const std::string MessageViewBase::url_for_copy()
+std::string MessageViewBase::url_for_copy() const
 {
     return DBTREE::url_readcgi( get_url(), 0, 0 );
 }
@@ -229,10 +229,36 @@ void MessageViewBase::init_color()
 {
     if( m_text_message ){
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+        if( CONFIG::get_use_message_gtktheme() ) {
+            m_text_message->update_style( u8"" );
+        }
+        else {
+            const char* const classname = m_text_message->get_css_classname();
+            const auto fg = Gdk::RGBA( CONFIG::get_color( COLOR_CHAR_MESSAGE ) ).to_string();
+            const auto bg = Gdk::RGBA( CONFIG::get_color( COLOR_BACK_MESSAGE ) ).to_string();
+            const auto sel_fg = Gdk::RGBA( CONFIG::get_color( COLOR_CHAR_MESSAGE_SELECTION ) ).to_string();
+            const auto sel_bg = Gdk::RGBA( CONFIG::get_color( COLOR_BACK_MESSAGE_SELECTION ) ).to_string();
+#if GTKMM_CHECK_VERSION(3,20,0)
+            constexpr const char* const caret_prop = u8"caret-color";
+#else
+            constexpr const char* const caret_prop = u8"-GtkWidget-cursor-color";
+#endif
+            m_text_message->update_style( Glib::ustring::compose(
+                u8R"(
+                    .%1, .%1 text { color: %2; background-color: %3; %4: %2; }
+                    .%1:selected, .%1:selected:focus,
+                    .%1 text:selected, .%1 text:selected:focus,
+                    .%1 text selection, .%1 text selection:focus { color: %5; background-color: %6; }
+                )",
+                classname, fg, bg, caret_prop, sel_fg, sel_bg ) );
+        }
+#else
         m_text_message->modify_text( Gtk::STATE_NORMAL, Gdk::Color( CONFIG::get_color( COLOR_CHAR_MESSAGE ) ) );
         m_text_message->modify_text( Gtk::STATE_SELECTED, Gdk::Color( CONFIG::get_color( COLOR_CHAR_MESSAGE_SELECTION ) ) );
         m_text_message->modify_base( Gtk::STATE_NORMAL, Gdk::Color( CONFIG::get_color( COLOR_BACK_MESSAGE ) ) );
         m_text_message->modify_base( Gtk::STATE_SELECTED, Gdk::Color( CONFIG::get_color( COLOR_BACK_MESSAGE_SELECTION ) ) );
+#endif // GTKMM_CHECK_VERSION(3,0,0)
     }
 }
 
@@ -243,7 +269,7 @@ void MessageViewBase::set_message( const std::string& msg )
 }
 
 
-const Glib::ustring MessageViewBase::get_message()
+Glib::ustring MessageViewBase::get_message()
 {
     if( m_text_message ) return m_text_message->get_text();
 
@@ -647,7 +673,7 @@ void MessageViewBase::write()
         const bool newline = true;
         const bool usemigemo = false;
         const bool wchar = false;
-        if( regex.exec( "%26%23[0-9]*%3b", msg, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.exec( "%26%23[0-9]+%3b", msg, offset, icase, newline, usemigemo, wchar ) ){
 
             SKELETON::MsgDiag mdiag( get_parent_win(),
                                      "ユニコード文字が含まれていますが、この板ではユニコード文字は文字化けします(BBS_UNICODE=change)。\n\n書き込みますか？",
@@ -993,10 +1019,16 @@ void MessageViewBase::show_status()
         m_lng_str_enc = str_enc.length();
 
         // 特殊文字の文字数を計算
-        m_lng_str_enc += MISC::count_chr( str_enc, '\n' ) * 5; // " <br> " = 6バイト
-        m_lng_str_enc += MISC::count_chr( str_enc, '"' ) * 5; // &quot; = 6バイト
-        m_lng_str_enc += MISC::count_chr( str_enc, '<' ) * 3; // &lt; = 4バイト
-        m_lng_str_enc += MISC::count_chr( str_enc, '>' ) * 3; // &gt; = 4バイト
+        for( const char c : str_enc ) {
+            if( c == '\n' || c == '"' ) {
+                // " <br> " = 6バイト,  &quot; = 6バイト
+                m_lng_str_enc += 5;
+            }
+            else if( c == '<' || c == '>' ) {
+                // &lt; = 4バイト, &gt; = 4バイト
+                m_lng_str_enc += 3;
+            }
+        }
 
         ss << m_lng_str_enc;
     }
