@@ -10,6 +10,11 @@
 #include "skeleton/compentry.h"
 #include "skeleton/jdtoolbar.h"
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+using GtkNotebookPage = Gtk::Widget;
+#endif
+
+
 namespace JDLIB
 {
     class Iconv;
@@ -91,7 +96,7 @@ namespace MESSAGE
         Gtk::Window* get_parent_win() override;
 
         // コピー用のURL
-        const std::string url_for_copy() override;
+        std::string url_for_copy() const override;
 
         // コマンド
         bool set_command( const std::string& command,
@@ -102,7 +107,7 @@ namespace MESSAGE
         bool is_loading() const override;
 
         // 規制中や行数や文字列がオーバーして書き込めない
-        bool is_broken() override { return ( ! m_str_pass.empty() || m_over_lines || m_over_lng ); }
+        bool is_broken() const override { return ( ! m_str_pass.empty() || m_over_lines || m_over_lng ); }
 
         // キーを押した        
         bool slot_key_press( GdkEventKey* event ) override;
@@ -152,7 +157,7 @@ namespace MESSAGE
         void slot_switch_page( GtkNotebookPage*, guint page );
         void slot_text_changed();
 
-        virtual const std::string create_message() = 0;
+        virtual std::string create_message() = 0;
 
         void show_status();
 
@@ -162,7 +167,7 @@ namespace MESSAGE
         SKELETON::Admin* get_admin() override;
 
         void set_message( const std::string& msg );
-        const Glib::ustring get_message();
+        Glib::ustring get_message();
 
         SKELETON::CompletionEntry& get_entry_name(){ return m_entry_name; }
         SKELETON::CompletionEntry& get_entry_mail(){ return m_entry_mail; }
