@@ -934,7 +934,7 @@ void SESSION::set_image_locked( const std::list< bool >& locked ){ image_locked
 
 // サイドバーのツールバーの項目
 const std::string& SESSION::get_items_sidebar_toolbar_str(){ return items_sidebar_toolbar_str; }
-const std::string SESSION::get_items_sidebar_toolbar_default_str()
+std::string SESSION::get_items_sidebar_toolbar_default_str()
 {
     return
     ITEM_NAME_SEARCHBOX + std::string ( " " ) +
@@ -951,7 +951,7 @@ int SESSION::get_item_sidebar_toolbar( const int num ){ return items_sidebar_too
 
 // メインツールバーの項目
 const std::string& SESSION::get_items_main_toolbar_str(){ return items_main_toolbar_str; }
-const std::string SESSION::get_items_main_toolbar_default_str()
+std::string SESSION::get_items_main_toolbar_default_str()
 {
     return
     ITEM_NAME_BBSLISTVIEW + std::string ( " " ) +
@@ -972,7 +972,7 @@ int SESSION::get_item_main_toolbar( const int num ){ return items_main_toolbar[
 
 // スレビューのツールバーの項目
 const std::string& SESSION::get_items_article_toolbar_str(){ return items_article_toolbar_str; }
-const std::string SESSION::get_items_article_toolbar_default_str()
+std::string SESSION::get_items_article_toolbar_default_str()
 {
     return
     ITEM_NAME_WRITEMSG + std::string ( " " ) +
@@ -994,7 +994,7 @@ int SESSION::get_item_article_toolbar( const int num ){ return items_article_too
 
 // 検索ビューのツールバーの項目
 const std::string& SESSION::get_items_search_toolbar_str(){ return items_search_toolbar_str; }
-const std::string SESSION::get_items_search_toolbar_default_str()
+std::string SESSION::get_items_search_toolbar_default_str()
 {
     return
     ITEM_NAME_NAME + std::string ( " " ) +
@@ -1012,7 +1012,7 @@ int SESSION::get_item_search_toolbar( const int num ){ return items_search_toolb
 
 // スレ一覧のツールバー項目
 const std::string& SESSION::get_items_board_toolbar_str(){ return items_board_toolbar_str; }
-const std::string SESSION::get_items_board_toolbar_default_str()
+std::string SESSION::get_items_board_toolbar_default_str()
 {
     return
     ITEM_NAME_NEWARTICLE + std::string ( " " ) +
@@ -1034,7 +1034,7 @@ int SESSION::get_item_board_toolbar( const int num ){ return items_board_toolbar
 
 // 書き込みビューのツールバー項目
 const std::string& SESSION::get_items_msg_toolbar_str(){ return items_msg_toolbar_str; }
-const std::string SESSION::get_items_msg_toolbar_default_str()
+std::string SESSION::get_items_msg_toolbar_default_str()
 {
     return
     ITEM_NAME_PREVIEW + std::string ( " " ) +
@@ -1054,7 +1054,7 @@ int SESSION::get_item_msg_toolbar( const int num ){ return items_msg_toolbar[ nu
 
 // スレ一覧の列項目
 const std::string& SESSION::get_items_board_col_str(){ return items_board_col_str; }
-const std::string SESSION::get_items_board_col_default_str()
+std::string SESSION::get_items_board_col_default_str()
 {
     return
     ITEM_NAME_MARK + std::string ( " " ) +
@@ -1076,7 +1076,7 @@ int SESSION::get_item_board_col( const int num ){ return items_board_col[ num ];
 
 // スレ一覧のコンテキストメニュー項目
 const std::string& SESSION::get_items_board_menu_str(){ return items_board_menu_str; }
-const std::string SESSION::get_items_board_menu_default_str()
+std::string SESSION::get_items_board_menu_default_str()
 {
     return
     ITEM_NAME_BOOKMARK + std::string ( " " ) +
@@ -1106,7 +1106,7 @@ int SESSION::get_item_board_menu( const int num ){ return items_board_menu[ num
 
 // スレビューのコンテキストメニュー項目
 const std::string& SESSION::get_items_article_menu_str(){ return items_article_menu_str; }
-const std::string SESSION::get_items_article_menu_default_str()
+std::string SESSION::get_items_article_menu_default_str()
 {
     return
     ITEM_NAME_DRAWOUT + std::string ( " " ) +
@@ -1166,7 +1166,7 @@ int SESSION::get_sidebar_current_page()
 }
 
 // 現在開いているサイドバーのurl
-const std::string SESSION::get_sidebar_current_url()
+std::string SESSION::get_sidebar_current_url()
 {
     return BBSLIST::get_admin()->get_current_url();
 }
@@ -1202,7 +1202,7 @@ ARTICLE::DrawAreaBase* SESSION::get_base_drawarea()
 
 
 // 現在開いているarticle のurl
-const std::string SESSION::get_article_current_url()
+std::string SESSION::get_article_current_url()
 {
     return ARTICLE::get_admin()->get_current_url();
 }
@@ -1360,7 +1360,7 @@ void SESSION::get_sidebar_threads( const std::string& url, const int dirid, std:
 
 
 // サイドバーの指定したidのディレクトリの名前を取得
-const std::string SESSION::get_sidebar_dirname( const std::string& url, const int dirid )
+std::string SESSION::get_sidebar_dirname( const std::string& url, const int dirid )
 {
     return BBSLIST::get_admin()->get_dirname( url, dirid );
 }
