@@ -1,6 +1,7 @@
 // ライセンス: GPL2
 
 //#define _DEBUG
+#include "gtkmmversion.h"
 #include "jddebug.h"
 
 #include "editview.h"
@@ -18,6 +19,10 @@
 
 #include "gtk/gtktextview.h"
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
+
 using namespace SKELETON;
 
 enum
@@ -348,6 +353,15 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::UndoEdit:
         case CONTROL::InputAA:
         {
+#if GTKMM_CHECK_VERSION(3,0,0)
+            if( im_context_filter_keypress( event ) ) {
+#ifdef _DEBUG
+                std::cout << "gtk_im_context_filter_keypress\n";
+#endif
+                reset_im_context();
+                return true;
+            }
+#else
             GtkTextView *textview = gobj();
             if( gtk_im_context_filter_keypress( textview->im_context, event ) )
             {
@@ -357,6 +371,7 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
                 textview->need_im_reset = TRUE;
                 return true;
             }
+#endif // GTKMM_CHECK_VERSION(3,0,0)
         }
     }
 
@@ -701,3 +716,47 @@ void EditTextView::slot_hide_aamenu()
 
     SESSION::set_popupmenu_shown( false );
 }
+
+
+//////////////////////////////////////////////
+
+EditView::EditView()
+    : Gtk::ScrolledWindow()
+{
+    set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC );
+    add( m_textview );
+#if GTKMM_CHECK_VERSION(3,0,0)
+    auto context = m_textview.get_style_context();
+    context->add_class( s_css_classname );
+    context->add_provider( m_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
+#endif
+    show_all_children();
+}
+
+
+EditView::~EditView() noexcept = default;
+
+
+#if GTKMM_CHECK_VERSION(3,0,0)
+constexpr const char* EditView::s_css_classname;
+#endif
+
+//
+// EditTextViewのスタイルを更新する
+//
+#if GTKMM_CHECK_VERSION(3,0,0)
+void EditView::update_style( const Glib::ustring& custom_css )
+{
+#ifdef _DEBUG
+        std::cout << "EditView::update_style custom css: " << custom_css << std::endl;
+#endif
+    try {
+        m_provider->load_from_data( custom_css );
+    }
+    catch( Gtk::CssProviderError& err ) {
+#ifdef _DEBUG
+        std::cout << "ERROR:EditView::update_style fail " << err.what() << std::endl;
+#endif
+    }
+}
+#endif // GTKMM_CHECK_VERSION(3,0,0)
