@@ -5,6 +5,8 @@
 #ifndef _PREFDIAG_H
 #define _PREFDIAG_H
 
+#include "gtkmmversion.h"
+
 #include <gtkmm.h>
 
 #include "jdlib/timeout.h"
@@ -46,6 +48,10 @@ namespace SKELETON
         virtual void slot_cancel_clicked(){}
         virtual void slot_apply_clicked(){}
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+        void set_default_size_ratio( double ratio );
+#endif
+
       private:
 
         // タイマーのslot関数
