@@ -46,6 +46,10 @@ enum
 
 using namespace SKELETON;
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+constexpr const char* JDWindow::s_css_stat_label;
+#endif
+
 // メッセージウィンドウでは m_mginfo が不要なので need_mginfo = false になる
 JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     : Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
@@ -69,6 +73,9 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     m_label_stat.set_alignment( Gtk::ALIGN_START );
     m_label_stat.set_selectable( true );
     m_label_stat.set_single_line_mode( true );
+#if GTKMM_CHECK_VERSION(2,6,0)
+    m_label_stat.set_ellipsize( Pango::ELLIPSIZE_END );
+#endif
 
     m_label_stat_ebox.add( m_label_stat );
     m_label_stat_ebox.set_visible_window( false );
@@ -94,6 +101,18 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     m_gtkwindow = GTK_WINDOW( gobj() );
     gpointer parent_class = g_type_class_peek_parent( G_OBJECT_GET_CLASS( gobj() ) );
     m_grand_parent_class = g_type_class_peek_parent( parent_class );
+
+#if GTKMM_CHECK_VERSION(3,0,0)
+    auto context = m_label_stat.get_style_context();
+    context->add_class( s_css_stat_label );
+    context->add_provider( m_stat_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
+
+    if( need_mginfo ) {
+        context = m_mginfo.get_style_context();
+        context->add_class( s_css_stat_label );
+        context->add_provider( m_stat_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
+    }
+#endif // GTKMM_CHECK_VERSION(3,0,0)
 }
 
 
@@ -227,7 +246,9 @@ void JDWindow::clock_in()
         // メインウィンドウと画像ウィンドウが同時にフォーカスアウトしたら
         // 一時的に transient 指定を外す。メインウィンドウがフォーカスインしたときに
         // Admin::focus_out() で transient 指定を戻す
-        if( ENVIRONMENT::get_wm() == ENVIRONMENT::WM_GNOME
+        using ENVIRONMENT::DesktopType;
+        const DesktopType wm = ENVIRONMENT::get_wm();
+        if( ( wm == DesktopType::gnome || wm == DesktopType::mate || wm == DesktopType::cinnamon )
             && ! SESSION::is_iconified_win_main() // メインウィンドウが最小化しているときに transient を外すとウィンドウが表示されなくなる
             && ! SESSION::is_focus_win_main() && ! is_focus_win() ){
 
@@ -437,12 +458,31 @@ void JDWindow::set_mginfo( const std::string& mginfo )
 // ステータスの色を変える
 void JDWindow::set_status_color( const std::string& color )
 {
-#if GTKMM_CHECK_VERSION(2,5,0)
-
 #ifdef _DEBUG
     std::cout << "JDWindow::set_status_color " << color << std::endl;
 #endif
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+    Glib::ustring css;
+    if( color.empty() ) {
+        // テキスト部分が上手く配色されないGTKテーマがあるので明示的に設定する
+        css = Glib::ustring::compose( u8".%1:not(:selected) { color: unset; }", s_css_stat_label );
+    }
+    else {
+        css = Glib::ustring::compose(
+            u8".%1:not(:selected), %1:active:not(:selected) { color: white; background-color: %2; }",
+            s_css_stat_label, Gdk::RGBA( color ).to_string() );
+    }
+    try {
+        m_stat_provider->load_from_data( css );
+    }
+    catch( Gtk::CssProviderError& err ) {
+#ifdef _DEBUG
+        std::cout << "ERROR:JDWindow::set_status_color fail " << err.what() << std::endl;
+#endif
+    }
+
+#elif GTKMM_CHECK_VERSION(2,5,0)
     if( color.empty() ){
 
         if( m_label_stat_ebox.get_visible_window() ){
@@ -509,7 +549,7 @@ void JDWindow::set_enable_fold( bool enable )
         // XFCE 環境の場合はここでpresent()しておかないとフォーカスが外れる
         if( m_mode == JDWIN_NORMAL && m_enable_fold ){
 
-            if( ENVIRONMENT::get_wm() == ENVIRONMENT::WM_KDE ) switch_admin();
+            if( ENVIRONMENT::get_wm() == ENVIRONMENT::DesktopType::kde ) switch_admin();
             else present();
         }
     }
