@@ -76,63 +76,11 @@ Usrcmd_Manager::Usrcmd_Manager()
 {
     std::string xml;
     if( CACHE::load_rawdata( CACHE::path_usrcmd(), xml ) ) m_document.init( xml );
-    else txt2xml();
 
     analyze_xml();
 }
 
 
-//
-// 旧式の設定ファイル(テキスト形式)をxmlに変換する
-//
-void Usrcmd_Manager::txt2xml()
-{
-    m_document.clear();
-
-    // 旧設定ファイルからユーザーコマンドを読み込み
-    const std::string file_usrcmd = CACHE::path_usrcmd_old();
-    std::string usrcmd;
-
-    if( CACHE::load_rawdata( file_usrcmd, usrcmd ) ){
-
-        XML::Dom* root = m_document.appendChild( XML::NODE_TYPE_ELEMENT, std::string( ROOT_NODE_NAME_USRCMD ) );
-        XML::Dom* subdir = root;
-
-        std::list< std::string > list_usrcmd = MISC::get_lines( usrcmd );
-        list_usrcmd = MISC::remove_commentline_from_list( list_usrcmd );
-        list_usrcmd = MISC::remove_space_from_list( list_usrcmd );
-        list_usrcmd = MISC::remove_nullline_from_list( list_usrcmd );
-
-        // ユーザコマンドが 3つ以上 (廃止した max_show_usrcmd 設定の初期値 )より
-        // 大きい場合はサブディレクトリ化する
-        if( list_usrcmd.size() >= 3 * 2 ){
-            subdir = root->appendChild( XML::NODE_TYPE_ELEMENT, XML::get_name( TYPE_DIR ) );
-            subdir->setAttribute( "name", "ユーザコマンド" );
-            subdir->setAttribute( "open", "y" );
-        }
-
-        std::list< std::string >::iterator it;
-        for( it = list_usrcmd.begin(); it != list_usrcmd.end(); ++it ){
-
-            const std::string name = *( it++ );
-            if( it == list_usrcmd.end() ) break;
-            const std::string cmd = *it;
-
-            XML::Dom* usrcmd = subdir->appendChild( XML::NODE_TYPE_ELEMENT, XML::get_name( TYPE_USRCMD ) );
-            usrcmd->setAttribute( "name", name );
-            usrcmd->setAttribute( "data", cmd );
-        }
-
-#ifdef _DEBUG
-        std::cout << "Usrcmd_Manager::txt2xml\n";
-        std::cout << "nodes = " << m_document.childNodes().size() << std::endl;
-        std::cout << m_document.get_xml() << std::endl;
-#endif
-        save_xml();
-    }
-}
-
-
 //
 // XML に含まれるコマンド情報を取り出してデータベースを更新
 //
@@ -291,12 +239,11 @@ bool Usrcmd_Manager::show_replacetextdiag( std::string& texti, const std::string
 // コマンド置換
 // cmdの$URLをurl, $LINKをlink, $TEXT*をtext, $NUMBERをnumberで置き換えて出力
 // text は UTF-8 であること
-const std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
-                                               const std::string& url,
-                                               const std::string& link,
-                                               const std::string& text,
-                                               const int number
-    )
+std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
+                                         const std::string& url,
+                                         const std::string& link,
+                                         const std::string& text,
+                                         const int number )
 {
     std::string cmd_out = cmd;
     const std::string oldhostl = DBTREE::article_org_host( link );
@@ -490,7 +437,7 @@ bool Usrcmd_Manager::is_hide( int num, const std::string& url )
 //
 // ユーザコマンドの登録とメニュー作成
 //
-const std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >& action_group )
+std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >& action_group )
 {
     int dirno = 0;
     int cmdno = 0;
@@ -499,8 +446,8 @@ const std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionG
 }
 
 // ユーザコマンドの登録とメニュー作成(再帰用)
-const std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >& action_group,
-                                                      XML::Dom* dom, int& dirno, int& cmdno )
+std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >& action_group,
+                                                XML::Dom* dom, int& dirno, int& cmdno )
 {
     std::string menu;
     if( ! dom ) return menu;
