@@ -90,12 +90,13 @@ UsrCmdPref::UsrCmdPref( Gtk::Window* parent, const std::string& url )
 
     m_scrollwin.add( m_treeview );
     m_scrollwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
+    m_scrollwin.set_size_request( 640, 400 );
 
     get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label );
+    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
     get_vbox()->pack_start( m_scrollwin );
 
-#if !GTKMM_CHECK_VERSION(2,7,0)
+#if GTKMM_CHECK_VERSION(2,7,0)
     m_ckbt_hide_usrcmd.set_active( CONFIG::get_hide_usrcmd() );
     get_vbox()->pack_start( m_ckbt_hide_usrcmd, Gtk::PACK_SHRINK );
 #endif
